@@ -1,7 +1,7 @@
 /**
     ConsistencyResults.h
  
-    Author: Matt Rice <ratmice@yahoo.com>
+    Author: Matt Rice <ratmice@gmail.com>
     Date: Jul 2005
 
     This file is part of DBModeler.
