@@ -4,7 +4,7 @@
 /*
     DefaultColumnProvider.h
  
-    Author: Matt Rice <ratmice@yahoo.com>
+    Author: Matt Rice <ratmice@gmail.com>
     Date: Apr 2005
 
     This file is part of DBModeler.
@@ -26,9 +26,9 @@
 
 #include <EOModeler/EOModelerApp.h>
 
-NSMutableArray *DefaultAttributeColumns;
-NSMutableArray *DefaultEntityColumns;
-NSMutableArray *DefaultRelationshipColumns;
+extern NSMutableArray *DefaultAttributeColumns;
+extern NSMutableArray *DefaultEntityColumns;
+extern NSMutableArray *DefaultRelationshipColumns;
 
 @interface DefaultColumnProvider : NSObject <EOMColumnProvider>
 {
