@@ -4,8 +4,8 @@
 /*
     MainModelerEditor.h
  
-    Author: Matt Rice <ratmice@yahoo.com>
-    Date: Apr 2005
+    Author: Matt Rice <ratmice@gmail.com>
+    Date: 2005, 2006
 
     This file is part of DBModeler.
 
