@@ -4,7 +4,7 @@
 /*
     ModelerAttributeEditor.h
  
-    Author: Matt Rice <ratmice@yahoo.com>
+    Author: Matt Rice <ratmice@gmail.com>
     Date: Apr 2005
 
     This file is part of DBModeler.
