@@ -6,11 +6,11 @@
    Author: Ovidiu Predescu <ovidiu@bx.logicnet.ro>
    Date: October 1996
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
-   $Revision: 21645 $
-   $Date: 2005-08-17 10:07:57 +0200 (Mit, 17 Aug 2005) $
+   $Revision: 24302 $
+   $Date: 2007-01-01 12:52:38 +0100 (Mon, 01 Jän 2007) $
 
    <abstract></abstract>
 
@@ -36,7 +36,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOAdaptor.m 21645 2005-08-17 08:07:57Z ayers $")
+RCS_ID("$Id: EOAdaptor.m 24302 2007-01-01 11:52:38Z ayers $")
 
 #if HAVE_LIBC_H
 # include <libc.h>
@@ -96,6 +96,47 @@ NSString *EOConnectionDictionaryKey = @"EOConnectionDictionaryKey";
 NSString *EOAdministrativeConnectionDictionaryKey 
   = @"EOAdministrativeConnectionDictionaryKey";
 
+/* This mapping should be kept in sync with NSStringEncoding in NSString.h.  */
+static struct { NSString *name; NSStringEncoding encoding; } encodingMap[] = {
+  { @"NSASCIIStringEncoding",         NSASCIIStringEncoding },
+  { @"NSNEXTSTEPStringEncoding",      NSNEXTSTEPStringEncoding },
+  { @"NSJapaneseEUCStringEncoding",   NSJapaneseEUCStringEncoding },
+  { @"NSUTF8StringEncoding",          NSUTF8StringEncoding },
+  { @"NSISOLatin1StringEncoding",     NSISOLatin1StringEncoding },
+  { @"NSSymbolStringEncoding",        NSSymbolStringEncoding },
+  { @"NSNonLossyASCIIStringEncoding", NSNonLossyASCIIStringEncoding },
+  { @"NSShiftJISStringEncoding",      NSShiftJISStringEncoding },
+  { @"NSISOLatin2StringEncoding",     NSISOLatin2StringEncoding },
+  { @"NSUnicodeStringEncoding",       NSUnicodeStringEncoding },
+  { @"NSWindowsCP1251StringEncoding", NSWindowsCP1251StringEncoding },
+  { @"NSWindowsCP1252StringEncoding", NSWindowsCP1252StringEncoding },
+  { @"NSWindowsCP1253StringEncoding", NSWindowsCP1253StringEncoding },
+  { @"NSWindowsCP1254StringEncoding", NSWindowsCP1254StringEncoding },
+  { @"NSWindowsCP1250StringEncoding", NSWindowsCP1250StringEncoding },
+  { @"NSISO2022JPStringEncoding",     NSISO2022JPStringEncoding },
+  { @"NSMacOSRomanStringEncoding",    NSMacOSRomanStringEncoding },
+  { @"NSProprietaryStringEncoding",   NSProprietaryStringEncoding },
+  { @"NSKOI8RStringEncoding",         NSKOI8RStringEncoding }, 
+  { @"NSISOLatin3StringEncoding",     NSISOLatin3StringEncoding },
+  { @"NSISOLatin4StringEncoding",     NSISOLatin4StringEncoding },
+  { @"NSISOCyrillicStringEncoding",   NSISOCyrillicStringEncoding },
+  { @"NSISOArabicStringEncoding",     NSISOArabicStringEncoding },
+  { @"NSISOGreekStringEncoding",      NSISOGreekStringEncoding },
+  { @"NSISOHebrewStringEncoding",     NSISOHebrewStringEncoding },
+  { @"NSISOLatin5StringEncoding",     NSISOLatin5StringEncoding },
+  { @"NSISOLatin6StringEncoding",     NSISOLatin6StringEncoding },
+  { @"NSISOThaiStringEncoding",       NSISOThaiStringEncoding },
+  { @"NSISOLatin7StringEncoding",     NSISOLatin7StringEncoding },
+  { @"NSISOLatin8StringEncoding",     NSISOLatin8StringEncoding },
+  { @"NSISOLatin9StringEncoding",     NSISOLatin9StringEncoding },
+  { @"NSGB2312StringEncoding",        NSGB2312StringEncoding },
+  { @"NSUTF7StringEncoding",          NSUTF7StringEncoding },
+  { @"NSGSM0338StringEncoding",       NSGSM0338StringEncoding },
+  { @"NSBIG5StringEncoding",          NSBIG5StringEncoding },
+  { @"NSKoreanEUCStringEncoding",     NSKoreanEUCStringEncoding },
+  { nil, 0 }
+};
+
 @implementation EOAdaptor
 
 + (id)adaptorWithModel: (EOModel *)model
@@ -143,7 +184,7 @@ NSString *EOAdministrativeConnectionDictionaryKey
   return adaptor;
 }
 
-+ (id) adaptorWithName: (NSString *)adaptorName
++ (id) adaptorWithName: (NSString *)name
 {
   //OK
   NSBundle *bundle = [NSBundle mainBundle];
@@ -154,7 +195,7 @@ NSString *EOAdministrativeConnectionDictionaryKey
   unsigned i, count;
 
   /* Check error */
-  if ([adaptorName length] == 0)
+  if ([name length] == 0)
     [NSException raise: NSInvalidArgumentException
 		 format: @"%@ -- %@ 0x%x: adaptor name can't be nil",
                  NSStringFromSelector(_cmd),
@@ -162,11 +203,11 @@ NSString *EOAdministrativeConnectionDictionaryKey
                  self];
   
   // append EOAdaptor
-  if ([adaptorName hasSuffix: @"EOAdaptor"] == NO)
-    adaptorName = [adaptorName stringByAppendingString: @"EOAdaptor"];
+  if ([name hasSuffix: @"EOAdaptor"] == NO)
+    name = [name stringByAppendingString: @"EOAdaptor"];
 
   /* Look in application bundle */
-  adaptorBundlePath = [bundle pathForResource: adaptorName
+  adaptorBundlePath = [bundle pathForResource: name
                               ofType: @"framework"];
   // should be NSString *path=[NSBundle pathForLibraryResource:libraryResource  type:@"framework"  directory:@"Frameworks"]; ?
 
@@ -189,7 +230,7 @@ NSString *EOAdministrativeConnectionDictionaryKey
       for(i = 0, count = [paths count]; i < count; i++)
         {
 	  bundle = [NSBundle bundleWithPath: [paths objectAtIndex: i]];
-	  adaptorBundlePath = [bundle pathForResource: adaptorName
+	  adaptorBundlePath = [bundle pathForResource: name
 				      ofType: @"framework"];
 	  
 	  if(adaptorBundlePath && [adaptorBundlePath length])
@@ -210,7 +251,7 @@ NSString *EOAdministrativeConnectionDictionaryKey
                  NSStringFromSelector(_cmd),
                  NSStringFromClass([self class]),
                  self,
-                 adaptorName];
+                 name];
   
   /* Get the adaptor bundle "infoDictionary", and pricipal class, ie. the
      adaptor class. Other info about the adaptor should be put in the
@@ -240,7 +281,7 @@ NSString *EOAdministrativeConnectionDictionaryKey
 		   NSStringFromSelector(_cmd),
 		   NSStringFromClass([self class]),
 		   self,
-		   adaptorName];
+		   name];
     }
       
   if ([adaptorClass isSubclassOfClass: [self class]] == NO)
@@ -253,7 +294,7 @@ NSString *EOAdministrativeConnectionDictionaryKey
 		   NSStringFromClass([adaptorClass class])];
     }
 
-  return AUTORELEASE([[adaptorClass alloc] initWithName: adaptorName]);
+  return AUTORELEASE([[adaptorClass alloc] initWithName: name]);
 }
 
 + (void)setExpressionClassName: (NSString *)sqlExpressionClassName
@@ -582,41 +623,41 @@ NSString *EOAdministrativeConnectionDictionaryKey
 
 - (NSStringEncoding)databaseEncoding
 {
-  NSString	   *encodingString=nil;
-  NSDictionary	   *encodingsDict = [self connectionDictionary];
-  const NSStringEncoding *availableEncodingsArray;
-  unsigned	    count = 0;
-  NSStringEncoding  availableEncodingValue;
-  NSString	   *availableEncodingString;
+  static NSMutableDictionary *encodingDictionary = nil;
+  NSDictionary *connectionDictionary;
+  NSString *encodingName;
+  NSString *encodingValue;
+  NSStringEncoding stringEncoding;
   
   EOFLOGObjectFnStartOrCond2(@"AdaptorLevel",@"EOAdaptor");
-  
-  if (encodingsDict
-      && (encodingString = [encodingsDict objectForKey: @"databaseEncoding"]))
+
+  if (encodingDictionary == nil)
     {
-      availableEncodingsArray = [NSString availableStringEncodings];
-    
-      while (availableEncodingsArray[count] != 0)
+      unsigned int i;
+      encodingDictionary = [[NSMutableDictionary alloc] initWithCapacity: 64];
+      for (i = 0; encodingMap[i].name != nil; i++)
 	{
-	  availableEncodingValue = availableEncodingsArray[count++];
+	  NSNumber *val = [NSNumber numberWithInt: encodingMap[i].encoding];
+	  [encodingDictionary setObject: val forKey: encodingMap[i].name];
+	}      
+    }
+  
+  connectionDictionary = [self connectionDictionary];
+  encodingName = [connectionDictionary objectForKey: @"databaseEncoding"];
+  encodingValue = [encodingDictionary objectForKey: encodingName];
 
-	  availableEncodingString = GSEncodingName(availableEncodingValue);
-
-	  if (availableEncodingString)
-	    {
-	      if ([availableEncodingString isEqual: encodingString])
-		{
-		  EOFLOGObjectFnStopOrCond2(@"AdaptorLevel", @"EOAdaptor");
-
-		  return availableEncodingValue;
-		}
-	    }
-	}
+  if (encodingValue == nil)
+    {
+      stringEncoding = [NSString defaultCStringEncoding];
+    }
+  else
+    {
+      stringEncoding = [encodingValue intValue];
     }
 
   EOFLOGObjectFnStopOrCond2(@"AdaptorLevel", @"EOAdaptor");
 
-  return [NSString defaultCStringEncoding];
+  return stringEncoding;
 }
 
 - (id)fetchedValueForValue: (id)value
