@@ -3,11 +3,11 @@
 
    Copyright (C) 2000,2002,2003,2004,2005 Free Software Foundation, Inc.
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
-   $Revision: 21645 $
-   $Date: 2005-08-17 10:07:57 +0200 (Mit, 17 Aug 2005) $
+   $Revision: 24302 $
+   $Date: 2007-01-01 12:52:38 +0100 (Mon, 01 Jän 2007) $
 
    <abstract></abstract>
 
@@ -33,7 +33,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOAdaptorChannel.m 21645 2005-08-17 08:07:57Z ayers $")
+RCS_ID("$Id: EOAdaptorChannel.m 24302 2007-01-01 11:52:38Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSString.h>
@@ -118,13 +118,13 @@ NSString *EOAdaptorOptimisticLockingFailure = @"EOAdaptorOptimisticLockingFailur
   [self subclassResponsibility: _cmd];
 }
 
-- (void)updateValues: (NSDictionary *)row
+- (void)updateValues: (NSDictionary *)values
 inRowDescribedByQualifier: (EOQualifier *)qualifier
 	      entity: (EOEntity *)entity
 {
   int rows;
 
-  rows = [self updateValues: row
+  rows = [self updateValues: values
 	       inRowsDescribedByQualifier: qualifier
 	       entity: entity];
 
