@@ -3,14 +3,14 @@
 
    Copyright (C) 2000-2002,2003,2004,2005 Free Software Foundation, Inc.
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 22681 $
-   $Date: 2006-03-19 19:03:50 +0100 (Son, 19 Mär 2006) $
+   $Revision: 24297 $
+   $Date: 2006-12-30 18:41:02 +0100 (Sam, 30 Dez 2006) $
 
    <abstract></abstract>
 
@@ -36,7 +36,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOAttribute.m 22681 2006-03-19 18:03:50Z ratmice $")
+RCS_ID("$Id: EOAttribute.m 24297 2006-12-30 17:41:02Z ayers $")
 
 #include <ctype.h>
 #include <string.h>
@@ -390,42 +390,6 @@ RCS_ID("$Id: EOAttribute.m 22681 2006-03-19 18:03:50Z ratmice $")
   [super dealloc];
 }
 
-- (void)gcDecrementRefCountOfContainedObjects
-{
-  EOFLOGObjectFnStart();
-
-  [_parent gcDecrementRefCount];
-  EOFLOGObjectLevel(@"gsdb", @"prototype gcDecrementRefCount");
-
-  [_prototype gcDecrementRefCount];
-  EOFLOGObjectLevel(@"gsdb", @"definitionArray gcDecrementRefCount");
-
-  [(id)_definitionArray gcDecrementRefCount];
-  EOFLOGObjectLevel(@"gsdb", @"realAttribute gcDecrementRefCount");
-
-  [_realAttribute gcDecrementRefCount];
-
-  EOFLOGObjectFnStop();
-}
-
-- (BOOL)gcIncrementRefCountOfContainedObjects
-{
-  if (![super gcIncrementRefCountOfContainedObjects])
-    return NO;
-
-  [_parent gcIncrementRefCount];
-  [_prototype gcIncrementRefCount];
-  [(id)_definitionArray gcIncrementRefCount];
-  [_realAttribute gcIncrementRefCount];
-
-  [_parent gcIncrementRefCountOfContainedObjects];
-  [_prototype gcIncrementRefCountOfContainedObjects];
-  [(id)_definitionArray gcIncrementRefCountOfContainedObjects];
-  [_realAttribute gcIncrementRefCountOfContainedObjects];
-  
-  return YES;
-}
-
 - (unsigned)hash
 {
   return [_name hash];
@@ -453,7 +417,7 @@ RCS_ID("$Id: EOAttribute.m 22681 2006-03-19 18:03:50Z ratmice $")
   return dscr;
 }
 
-/* We override GCObjects default implementation
+/* We override NSObjects default implementation
    as attributes cannot be copied */
 - (id)copyWithZone:(NSZone *)zone
 {
@@ -646,6 +610,23 @@ RCS_ID("$Id: EOAttribute.m 22681 2006-03-19 18:03:50Z ratmice $")
   return isFlattened;
 }
 
+/**
+ * <p>Returns the name of the class values of this attribute
+ * are represented by.  The standard classes are NSNumber,
+ * NSString, NSData and NSDate for the corresponding
+ * [-adaptorValueType].  A model can define more specific
+ * classes like NSDecimalNumber, NSCalendarDate and NSImage
+ * or custom classes which implement a factory method
+ * specified by [-valueFactoryMethodName] to create instances
+ * with the data supplied by the data source.</p>
+ * <p>If the valueClassName has not been set explicitly and the 
+ * reciever [-isFlattened], the valueClassName of the flattened
+ * attribute is returned.</p>
+ * <p>Otherwise, if the reciever has a prototype then the
+ * valueClassName of the prototype is returned.</p>
+ * <p>If all that fails, this method returns nil.</p>
+ * <p>See also:[setValueClassName:]</p>
+ */
 - (NSString *)valueClassName
 {
   if (_valueClassName)
@@ -657,6 +638,16 @@ RCS_ID("$Id: EOAttribute.m 22681 2006-03-19 18:03:50Z ratmice $")
   return [_prototype valueClassName];
 }
 
+/**
+ * <p>Returns the adaptor specific name of externalType.  This is
+ * the name use during SQL generation.</p>
+ * <p>If the externalType has not been set explicitly and the 
+ * reciever [-isFlattened], the valueClassName of the flattened
+ * attribute is returned.</p>
+ * <p>Otherwise, if the reciever has a prototype then the
+ * externalType of the prototype is returned.</p>
+ * <p>If all that fails, this method returns nil.</p>
+ */
 - (NSString *)externalType
 {
   if (_externalType)
@@ -668,6 +659,30 @@ RCS_ID("$Id: EOAttribute.m 22681 2006-03-19 18:03:50Z ratmice $")
   return [_prototype externalType];
 }
 
+/**
+ * <p>Returns a one character string identifiying the underlying
+ * C type of an NSNumber [-valueType].  The legal values in GDL2 are:</p>
+ * <list>
+ * <item>@"c": char</item>
+ * <item>@"C": unsigned char</item>
+ * <item>@"s": short</item>
+ * <item>@"S": unsigned short</item>
+ * <item>@"i": int</item>
+ * <item>@"I": unsigned int</item>
+ * <item>@"l": long</item>
+ * <item>@"L": unsigned long</item>
+ * <item>@"u": long long</item>
+ * <item>@"U": unsigned long long</item>
+ * <item>@"f": float</item>
+ * <item>@"d": double</item>
+ * </list>
+ * <p>If the valueType has not been set explicitly and the 
+ * reciever [-isFlattened], the valueClassName of the flattened
+ * attribute is returned.</p>
+ * <p>Otherwise, if the reciever has a prototype then the
+ * valueType of the prototype is returned.</p>
+ * <p>If all that fails, this method returns nil.</p>
+ */
 - (NSString *)valueType
 {
   if (_valueType)
@@ -906,9 +921,9 @@ return nexexp
   ASSIGN(_valueType, type);
 
   if ([_valueType length]==1)
-    _valueTypeChar=(char)[_valueType characterAtIndex:0];
+    _valueTypeCharacter = [_valueType characterAtIndex:0];
   else
-    _valueTypeChar='\0';
+    _valueTypeCharacter = '\0';
 
   [self _setOverrideForKeyEnum: 4];//TODO
 }
@@ -1197,13 +1212,10 @@ return nexexp
         {
 	case EOFactoryMethodArgumentIsNSString:
 	  {
-	    NSData *data = nil;
             NSString *string = nil;
 
-	    data = AUTORELEASE([(GDL2_alloc(NSData)) initWithBytes: bytes
-						     length: length]);
-
-            string = [(GDL2_alloc(NSString)) initWithData: data
+            string = [(GDL2_alloc(NSString)) initWithBytes: bytes
+					     length: length
                                              encoding: encoding];
 
             // If we have a value factiry method, call it to get the final value
@@ -1276,12 +1288,9 @@ return nexexp
     
   if(!value)
     {
-      NSData *data;
-      data = AUTORELEASE([(GDL2_alloc(NSData)) initWithBytes: bytes
-					       length: length]);
-
       //For efficiency reasons, the returned value is NOT autoreleased !
-      value = [(GDL2_alloc(NSString)) initWithData: data
+      value = [(GDL2_alloc(NSString)) initWithBytes: bytes
+				      length: length
 				      encoding: encoding];
     }
   
@@ -1324,30 +1333,31 @@ return nexexp
   return date;
 }
 
-/** Returns the name of the method to use for creating a custom class 
-value for this attribute.
-
-See Also: - valueFactoryMethod, -newValueForBytes:length:
-**/
+/**
+ * <p>Returns the name of the method to use for creating a custom class 
+ * value for this attribute.</p>
+ * See Also: [-valueFactoryMethod], [-newValueForBytes:length:]
+ */
 - (NSString *)valueFactoryMethodName
 {
   return _valueFactoryMethodName;
 }
 
-/** Returns the selector of the method to use for creating a custom class 
-value for this attribute.
-Default implementation returns selector for name returned by 
--valueFactoryMethodName or NULL if no selector is found.
-
-See Also: - valueFactoryMethodName, -newValueForBytes:length:
-**/
+/**
+ * <p>Returns the selector of the method to use for creating a custom class 
+ * value for this attribute.</p>
+ * <p>Default implementation returns selector for name returned by 
+ * [-valueFactoryMethodName] or NULL if no selector is found.</p>
+ *
+ * See Also: [-valueFactoryMethodName], [-newValueForBytes:length:]
+ */
 - (SEL)valueFactoryMethod
 {
   return _valueFactoryMethod;
 }
 
 /**
- * Depending on -adaptorValueType this method checks whether the value
+ * Depending on [-adaptorValueType] this method checks whether the value
  * is a NSNumber, NSString, NSData or NSDate instance respectively.
  * If not, it attempts to retrieve the -adaptorValueConversionMethod
  * which should be used to convert the value accordingly.  If none
@@ -1404,7 +1414,8 @@ See Also: - valueFactoryMethodName, -newValueForBytes:length:
                 }
               else
                 {
-                  /* This exception might not be conformant, but seems helpful.  */
+                  /* This exception might not be conformant, 
+		     but seems helpful.  */
                   [NSException raise: NSInvalidArgumentException
                                format: @"Value of class: %@ needs conversion "
                                @"yet no conversion method specified. "
@@ -1422,38 +1433,49 @@ See Also: - valueFactoryMethodName, -newValueForBytes:length:
   return value;
 }
 
-/** Returns method name to use to convert value of a class 
-different than attribute adaptor value type. 
-
-See also: -adaptorValueByConvertingAttributeValue, -adaptorValueConversionMethod
-**/
+/**
+ * <p>Returns method name to use to convert value of a class 
+ * different than attribute adaptor value type.</p>
+ * 
+ * See also: [-adaptorValueByConvertingAttributeValue:], 
+ * [-adaptorValueConversionMethod]
+ */
 - (NSString *)adaptorValueConversionMethodName
 {
   return _adaptorValueConversionMethodName;
 }
 
-/** Returns selector of the method to use to convert value of a class 
-different than attribute adaptor value type. 
-Default implementation returns selector of method returned by 
-adaptorValueConversionMethodName or NULL if there's not selector for the method
-
-See also: -adaptorValueByConvertingAttributeValue, -adaptorValueConversionMethodName
-**/
+/** 
+ * <p>Returns selector of the method to use to convert value of a class 
+ * different than attribute adaptor value type.</p>
+ * <p>The default implementation returns the selector corresponding to 
+ * [-adaptorValueConversionMethodName] or NULL if there's not selector
+ * for the method.</p>
+ *
+ * See also: [-adaptorValueByConvertingAttributeValue:],
+ * [-adaptorValueConversionMethodName]
+ */
 - (SEL)adaptorValueConversionMethod
 {
   return _adaptorValueConversionMethod;
 }
 
-/** Returns an EOAdaptorValueType describing the adaptor 
-(i.e. database) type of data for this attribute.
-
-Returned value can be:
-EOAdaptorBytesType 	Raw bytes (default type)
-EOAdaptorNumberType 	Number value (attribute valueClass is kind of NSNumber)
-EOAdaptorCharactersType String value (attribute valueClass is kind of NSString)
-EOAdaptorDateType 	Date value (attribute valueClass is kind of NSDate)
-
-**/
+/**
+ * <p>Returns an EOAdaptorValueType describing the adaptor 
+ * (i.e. database) type of data for this attribute.</p>
+ *
+ * <p>Returned value can be:</p>
+ * <list>
+ * <item>EOAdaptorBytesType
+ * 	Raw bytes (default type)</item>
+ * <item>EOAdaptorNumberType 
+ *	Number value (attribute valueClass is kind of NSNumber) </item>
+ * <item>EOAdaptorCharactersType
+ *	String value (attribute valueClass is kind of NSString)</item>
+ * <item>EOAdaptorDateType
+ * 	Date value (attribute valueClass is kind of NSDate)</item>
+ * </list>
+ */
 - (EOAdaptorValueType)adaptorValueType
 {
   if (!_flags.isAttributeValueInitialized)
@@ -1528,19 +1550,20 @@ See also: -setFactoryMethodArgumentType:
   _valueFactoryMethod = NSSelectorFromString(_valueFactoryMethodName);
 }
 
-/** Set method name to use to convert value of a class 
-different than attribute adaptor value type. 
-
-See also: -adaptorValueByConvertingAttributeValue, -adaptorValueConversionMethod, 
-	-adaptorValueConversionMethodName
-**/
-
+/** 
+ * <p>Set method name to use to convert value of a class 
+ * different than attribute adaptor value type.</p>
+ *
+ * See also: [-adaptorValueByConvertingAttributeValue:], 
+ * [-adaptorValueConversionMethod], [-adaptorValueConversionMethodName]
+ */
 - (void)setAdaptorValueConversionMethodName: (NSString *)conversionMethodName
 {
   [self willChange];
   ASSIGN(_adaptorValueConversionMethodName, conversionMethodName);
 
-  _adaptorValueConversionMethod = NSSelectorFromString(_adaptorValueConversionMethodName);
+  _adaptorValueConversionMethod 
+    = NSSelectorFromString(_adaptorValueConversionMethodName);
 }
 
 /** Set the type of argument needed by the factoryMethod.
@@ -1659,8 +1682,8 @@ More details:
                     {
                       if (valueClass == GDL2_NSNumberClass)
                         {
-                          char valueTypeChar=[self _valueTypeChar];
-                          switch(valueTypeChar)
+                          unichar valueTypeCharacter = [self _valueTypeCharacter];
+                          switch(valueTypeCharacter)
                             {
                             case 'i':
                               *valueP = [GDL2_alloc(NSNumber) 
@@ -1839,7 +1862,7 @@ More details:
   return _realAttribute;
 }
 
-- (GCMutableArray *)_definitionArray
+- (NSMutableArray *)_definitionArray
 {
   return _definitionArray;
 }
@@ -1854,17 +1877,26 @@ More details:
     return [_prototype _valueClass];
 }
 
-- (char)_valueTypeChar
+/*
+ * This method returns the valueType as a unichar character.
+ * The value of the instance variable get set implicitly
+ * if the valueType is set explicitly with a legal value.
+ * Otherwise the effective valueType of reciever is used.
+ * TODO: Once this has been set later implicit changes to the
+ * valueType via flattend attrubutes or prototypes will not
+ * be honored.  Value validation can be a hot spot so this method
+ * (or rather it's only use in validateValue:) should remain efficient.
+ */
+- (unichar)_valueTypeCharacter
 {
-  char valueTypeChar=_valueTypeChar;
-  if (valueTypeChar=='\0')
+  unichar valueTypeCharacter = _valueTypeCharacter;
+  if (valueTypeCharacter == '\0')
     {
-      // Compute it
-      NSString* valueType=[self valueType];
-      if ([valueType length]==1)
-        valueTypeChar=(char)[valueType characterAtIndex:0];
+      NSString* valueType = [self valueType];
+      if ([valueType length] == 1)
+        valueTypeCharacter = [valueType characterAtIndex:0];
     }
-  return valueTypeChar;
+  return valueTypeCharacter;
 };
 
 @end
