@@ -3,14 +3,14 @@
 
    Copyright (C) 2000-2002,2003,2004,2005 Free Software Foundation, Inc.
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: June 2000
 
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 21645 $
-   $Date: 2005-08-17 10:07:57 +0200 (Mit, 17 Aug 2005) $
+   $Revision: 24302 $
+   $Date: 2007-01-01 12:52:38 +0100 (Mon, 01 Jän 2007) $
 
    <abstract></abstract>
 
@@ -36,7 +36,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EODatabaseChannel.m 21645 2005-08-17 08:07:57Z ayers $")
+RCS_ID("$Id: EODatabaseChannel.m 24302 2007-01-01 11:52:38Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSString.h>
@@ -223,7 +223,7 @@ RCS_ID("$Id: EODatabaseChannel.m 21645 2005-08-17 08:07:57Z ayers $")
   ASSIGN(_currentEditingContext, context);
 }
 
-- (void)selectObjectsWithFetchSpecification: (EOFetchSpecification *)fetch
+- (void)selectObjectsWithFetchSpecification: (EOFetchSpecification *)fetchSpecification
 			     editingContext: (EOEditingContext *)context
 {
   //should be OK
@@ -235,7 +235,7 @@ RCS_ID("$Id: EODatabaseChannel.m 21645 2005-08-17 08:07:57Z ayers $")
 
   EOFLOGObjectFnStart();
 
-  entityName = [fetch entityName];
+  entityName = [fetchSpecification entityName];
   database = [_databaseContext database];
 
   EOFLOGObjectLevelArgs(@"gsdb", @"database=%@", database);
@@ -244,7 +244,7 @@ RCS_ID("$Id: EODatabaseChannel.m 21645 2005-08-17 08:07:57Z ayers $")
 
   EOFLOGObjectLevelArgs(@"gsdb", @"entity name=%@", [entity name]);
 
-  qualifier=[fetch qualifier];
+  qualifier=[fetchSpecification qualifier];
 
   EOFLOGObjectLevelArgs(@"gsdb", @"qualifier=%@", qualifier);
 
@@ -259,18 +259,18 @@ RCS_ID("$Id: EODatabaseChannel.m 21645 2005-08-17 08:07:57Z ayers $")
     {
       EOFetchSpecification *newFetch = nil;
 
-      EOFLOGObjectLevelArgs(@"gsdb", @"fetch=%@", fetch);
+      EOFLOGObjectLevelArgs(@"gsdb", @"fetchSpecification=%@", fetchSpecification);
       //howto avoid copy of uncopiable qualifiers (i.e. those who contains uncopiable key or value)
 
-      EOFLOGObjectLevelArgs(@"gsdb", @"fetch=%@", fetch);
+      EOFLOGObjectLevelArgs(@"gsdb", @"fetchSpecification=%@", fetchSpecification);
 
-      newFetch = [[fetch copy] autorelease];
+      newFetch = [[fetchSpecification copy] autorelease];
       EOFLOGObjectLevelArgs(@"gsdb", @"newFetch=%@", newFetch);
 
       [newFetch setQualifier: schemaBasedQualifier];
       EOFLOGObjectLevelArgs(@"gsdb", @"newFetch=%@", newFetch);
 
-      fetch = newFetch;
+      fetchSpecification = newFetch;
     }
 
   EOFLOGObjectLevelArgs(@"gsdb", @"%@ -- %@ 0x%x: isFetchInProgress=%s",
@@ -279,7 +279,7 @@ RCS_ID("$Id: EODatabaseChannel.m 21645 2005-08-17 08:07:57Z ayers $")
 	       self,
 	       ([self isFetchInProgress] ? "YES" : "NO"));
 
-  [self _selectWithFetchSpecification:fetch
+  [self _selectWithFetchSpecification:fetchSpecification
         editingContext:context];
 
   EOFLOGObjectFnStop();
