@@ -3,12 +3,12 @@
 
    Copyright (C) 2000-2002,2003,2004,2005 Free Software Foundation, Inc.
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
            Manuel Guesdon <mguesdon@orange-concept.com>
    Date: February 2000
 
-   $Revision: 22681 $
-   $Date: 2006-03-19 19:03:50 +0100 (Son, 19 Mär 2006) $
+   $Revision: 24302 $
+   $Date: 2007-01-01 12:52:38 +0100 (Mon, 01 Jän 2007) $
 
    <abstract></abstract>
 
@@ -34,7 +34,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOModel.m 22681 2006-03-19 18:03:50Z ratmice $")
+RCS_ID("$Id: EOModel.m 24302 2007-01-01 11:52:38Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSBundle.h>
@@ -211,12 +211,12 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
       _version = DEFAULT_MODEL_VERSION;
       _flags.createsMutableObjects = YES;
       
-      _entitiesByName = [GCMutableDictionary new];
+      _entitiesByName = [NSMutableDictionary new];
       _entitiesByClass = NSCreateMapTableWithZone(NSObjectMapKeyCallBacks, 
 						  NSObjectMapValueCallBacks,
 						  8,
 						  [self zone]);
-      _storedProcedures = [GCMutableArray new];
+      _storedProcedures = [NSMutableArray new];
   
       [[NSNotificationCenter defaultCenter]
         addObserver: self
@@ -248,13 +248,16 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
 - (void) dealloc
 {
   [[NSNotificationCenter defaultCenter] removeObserver: self];
-
+  [[self entities] makeObjectsPerformSelector:@selector(_setModel:)
+	  			withObject:nil];
   if (_entitiesByClass)
     {
       NSFreeMapTable(_entitiesByClass);
       _entitiesByClass = NULL;
     }
-
+  DESTROY(_storedProcedures);
+  DESTROY(_entitiesByName);
+  DESTROY(_entities);
   DESTROY(_name);
   DESTROY(_path);
   DESTROY(_adaptorName);
@@ -266,47 +269,6 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
   [super dealloc];
 }
 
-- (void) gcDecrementRefCountOfContainedObjects
-{
-  EOFLOGObjectFnStart();
-
-  [(id)_group gcDecrementRefCount];
-  EOFLOGObjectLevel(@"gsdb", @"entities gcDecrementRefCount");
-
-  [(id)_entities gcDecrementRefCount];
-  EOFLOGObjectLevel(@"gsdb", @"entitiesByName gcDecrementRefCount");
-
-  [(id)_entitiesByName gcDecrementRefCount];
-  EOFLOGObjectLevel(@"gsdb", @"storedProcedures gcDecrementRefCount");
-
-  [(id)_storedProcedures gcDecrementRefCount];
-  EOFLOGObjectLevel(@"gsdb", @"subEntitiesCache gcDecrementRefCount");
-
-  [(id)_subEntitiesCache gcDecrementRefCount];
-
-  EOFLOGObjectFnStop();
-}
-
-- (BOOL) gcIncrementRefCountOfContainedObjects
-{
-  if (![super gcIncrementRefCountOfContainedObjects])
-    return NO;
-
-  [(id)_group gcIncrementRefCount];
-  [(id)_entities gcIncrementRefCount];
-  [(id)_entitiesByName gcIncrementRefCount];
-  [(id)_storedProcedures gcIncrementRefCount];
-  [(id)_subEntitiesCache gcIncrementRefCount];
-
-  [(id)_group gcIncrementRefCountOfContainedObjects];
-  [(id)_entities gcIncrementRefCountOfContainedObjects];
-  [(id)_entitiesByName gcIncrementRefCountOfContainedObjects];
-  [(id)_storedProcedures gcIncrementRefCountOfContainedObjects];
-  [(id)_subEntitiesCache gcIncrementRefCountOfContainedObjects];
-
-  return YES;
-}
-
 - (NSString*) path
 {
   return _path;
@@ -604,7 +566,6 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
 {
   NSFileManager		*mgr = [NSFileManager defaultManager];
   NSMutableDictionary	*pList;
-  NSDictionary		*attributes;
   NSDictionary		*entityPList;
   NSDictionary		*stProcPList;
   NSEnumerator		*entityEnum;
@@ -660,12 +621,8 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
 
   [self encodeIntoPropertyList: pList];
 
-  attributes = [NSDictionary dictionaryWithObjectsAndKeys:
-    [NSNumber numberWithUnsignedLong: 0777], NSFilePosixPermissions,
-    nil];
-
   if (writeSingleFile == NO
-      && [mgr createDirectoryAtPath: path attributes: attributes] == NO)
+      && [mgr createDirectoryAtPath: path attributes: nil] == NO)
     {
       NSString *fmt;
       fmt = [NSString stringWithFormat: @"Could not create directory: %@",
@@ -890,6 +847,7 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
     {
       NSMutableDictionary *entityPList;
       EOEntity *entity;
+      EOEntity *parent;
 
       entity = [_entities objectAtIndex: i];
       entityPList = [NSMutableDictionary dictionaryWithCapacity: 2];
@@ -897,6 +855,10 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
       [entityPList setObject: [entity className] forKey: @"className"];
       [entityPList setObject: [entity name] forKey: @"name"];
 
+      parent = [entity parentEntity];
+      if (parent)
+        [entityPList setObject: [parent name] forKey: @"parent"];
+
       [entitiesArray addObject: entityPList];
     }
 
@@ -1049,6 +1011,7 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
 
 - (void)awakeWithPropertyList: (NSDictionary *)propertyList
 {
+  return;
 }
 
 - (void)encodeIntoPropertyList: (NSMutableDictionary *)propertyList
@@ -1284,15 +1247,17 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
              forParent: (id)param1
 {
   // TODO [self notImplemented:_cmd];
+  return;
 }
 
 - (void) _setInheritanceLinks: (id)param0
 {
   // TODO
   [self notImplemented: _cmd];
+  return;
 }
 
-- (void) _removeEntity: (id)entity
+- (void) _removeEntity: (EOEntity *)entity
 {
   //should be ok
   NSString *entityName = nil;
@@ -1300,13 +1265,13 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
 
   if ([entity isKindOfClass: [EOEntity class]])
     {
-      entityName = [(EOEntity*)entity name];
+      entityName = [entity name];
       entityClassName = [entity className];
     }
   else
     {
-      entityName = [entity objectForKey: @"name"];
-      entityClassName = [entity  objectForKey: @"className"];
+      entityName = [(NSDictionary *)entity objectForKey: @"name"];
+      entityClassName = [(NSDictionary *)entity  objectForKey: @"className"];
     }
 
   [_entitiesByName removeObjectForKey: entityName];
@@ -1341,6 +1306,7 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
       //may be: self  _registerChild:(id)param0
       //             forParent:entity...
     }
+  [entity awakeWithPropertyList:propertyList];
 
   [[NSNotificationCenter defaultCenter]
     postNotificationName: @"EOEntityLoadedNotification"
@@ -1481,10 +1447,10 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
   [self willChange];
   /* Do not access _entities until cache is triggered */
   if ([self createsMutableObjects])
-    [(GCMutableArray *)[self entities] addObject: entity];
+    [(NSMutableArray *)[self entities] addObject: entity];
   else
     {
-      id e = [GCMutableArray arrayWithArray: [self entities]];
+      id e = [NSMutableArray arrayWithArray: [self entities]];
 
       [e addObject: entity];
       ASSIGNCOPY(_entities, e);
@@ -1522,17 +1488,17 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
 
   /* Do not access _entities until cache is triggered */
   if ([self createsMutableObjects])
-    [(GCMutableArray *)[self entities] removeObject: entity];
+    [(NSMutableArray *)[self entities] removeObject: entity];
   else
     {
-      id e = [GCMutableArray arrayWithArray: [self entities]];
+      id e = [NSMutableArray arrayWithArray: [self entities]];
 
       [e removeObject: entity];
       ASSIGNCOPY(_entities, e);
     }
 }
 
-- (void) removeEntityAndReferences: (EOEntity *)entity;
+- (void) removeEntityAndReferences: (EOEntity *)entity
 {
   [self removeEntity: entity];
   // TODO;
@@ -1550,14 +1516,10 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
   NSAssert(_storedProcedures, @"Uninitialised _storedProcedures!");
   [self willChange];
   if ([self createsMutableObjects])
-    [(GCMutableArray *)_storedProcedures addObject: storedProcedure];
+    [(NSMutableArray *)_storedProcedures addObject: storedProcedure];
   else
     {
-      NSMutableArray *mCopy = AUTORELEASE([_storedProcedures mutableCopy]);
-      [mCopy removeObject: storedProcedure];
-      mCopy = AUTORELEASE([[GCArray alloc] initWithArray: mCopy
-					   copyItems: NO]);
-      ASSIGN(_storedProcedures, mCopy);
+      _storedProcedures = RETAIN([AUTORELEASE(_storedProcedures) arrayByAddingObject:storedProcedure]);
     }
 }
 
@@ -1567,12 +1529,12 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
 
   [self willChange];
   if ([self createsMutableObjects])
-    [(GCMutableArray *)_storedProcedures removeObject: storedProcedure];
+    [(NSMutableArray *)_storedProcedures removeObject: storedProcedure];
   else
     {
       NSMutableArray *mCopy = AUTORELEASE([_storedProcedures mutableCopy]);
       [mCopy removeObject: storedProcedure];
-      mCopy = AUTORELEASE([[GCArray alloc] initWithArray: mCopy
+      mCopy = AUTORELEASE([[NSArray alloc] initWithArray: mCopy
 					   copyItems: NO]);
       ASSIGN(_storedProcedures, mCopy);
     }
@@ -1791,12 +1753,12 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
       /* Do not access _entities until cache is triggered */
       if (_flags.createsMutableObjects)
 	{
-	  entityArray = [[GCMutableArray alloc] initWithArray: entityArray
+	  entityArray = [[NSMutableArray alloc] initWithArray: entityArray
 						copyItems:NO];
 	}
       else
 	{
-	  entityArray = [[GCArray alloc] initWithArray: entityArray
+	  entityArray = [[NSArray alloc] initWithArray: entityArray
 					 copyItems:NO];
 	}
       ASSIGN(_entities, entityArray);
@@ -1900,12 +1862,12 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
   NSString *className;
   unsigned int i,c;
 
-  DESTROY(_entitiesByName);
   DESTROY(_subEntitiesCache);
   NSResetMapTable(_entitiesByClass);
 
   names = [_entities valueForKey: @"name"];
-  _entitiesByName = [[GCMutableDictionary alloc] initWithObjects: _entities
+  DESTROY(_entitiesByName);
+  _entitiesByName = [[NSMutableDictionary alloc] initWithObjects: _entities
 						 forKeys: names];
   for (i = 0, c = [_entities count]; i < c; i++)
     {
@@ -1915,3 +1877,4 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
     }
 }
 @end /* EOModel (EOModelPrivate) */
+
