@@ -3,14 +3,14 @@
 
    Copyright (C) 2000-2002,2003,2004,2005 Free Software Foundation, Inc.
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 23472 $
-   $Date: 2006-09-12 21:36:24 +0200 (Die, 12 Sep 2006) $
+   $Revision: 25102 $
+   $Date: 2007-05-01 14:01:43 +0200 (Die, 01 Mai 2007) $
 
    <abstract></abstract>
 
@@ -36,7 +36,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EORelationship.m 23472 2006-09-12 19:36:24Z ayers $")
+RCS_ID("$Id: EORelationship.m 25102 2007-05-01 12:01:43Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSArray.h>
@@ -100,7 +100,7 @@ RCS_ID("$Id: EORelationship.m 23472 2006-09-12 19:36:24Z ayers $")
       _destinationNames = [NSMutableDictionary new];
       _userInfo = [NSDictionary new];
       _sourceToDestinationKeyMap = [NSDictionary new];
-      _joins = [GCMutableArray new];
+      _joins = [NSMutableArray new];
 */
     }
 
@@ -122,82 +122,6 @@ RCS_ID("$Id: EORelationship.m 23472 2006-09-12 19:36:24Z ayers $")
   [super dealloc];
 }
 
-- (void)gcDecrementRefCountOfContainedObjects
-{
-  EOFLOGObjectFnStart();
-
-  EOFLOGObjectLevelArgs(@"EORelationship", @"self=%@", self);
-
-  EOFLOGObjectLevel(@"EORelationship",
-		    @"definitionArray gcDecrementRefCount");
-  [(id)_definitionArray gcDecrementRefCount];
-
-  EOFLOGObjectLevel(@"EORelationship",
-		    @"_inverseRelationship gcDecrementRefCount");
-  [_inverseRelationship gcDecrementRefCount];
-
-  EOFLOGObjectLevel(@"EORelationship",
-		    @"_hiddenInverseRelationship gcDecrementRefCount");
-  [_hiddenInverseRelationship gcDecrementRefCount];
-
-  EOFLOGObjectLevel(@"EORelationship", @"_entity gcDecrementRefCount");
-  [_entity gcDecrementRefCount];
-
-  EOFLOGObjectLevel(@"EORelationship",
-		    @"_destination gcDecrementRefCount");
-  [_destination gcDecrementRefCount];
-
-  EOFLOGObjectLevelArgs(@"EORelationship",
-			@"_joins %p gcDecrementRefCount (class=%@)",
-			_joins, [_joins class]);
-  [(id)_joins gcDecrementRefCount];
-
-  EOFLOGObjectLevelArgs(@"EORelationship",
-			@"_sourceAttributes gcDecrementRefCount (class=%@)",
-			[_sourceAttributes class]);
-  [(id)_sourceAttributes gcDecrementRefCount];
-
-  EOFLOGObjectLevelArgs(@"EORelationship",
-			@"_destinationAttributes gcDecrementRefCount (class=%@)",
-			[_destinationAttributes class]);
-  [(id)_destinationAttributes gcDecrementRefCount];
-
-  EOFLOGObjectLevelArgs(@"EORelationship",
-			@"_componentRelationships gcDecrementRefCount (class=%@)",
-			[_componentRelationships class]);
-  [(id)_componentRelationships gcDecrementRefCount];
-
-  EOFLOGObjectFnStop();
-}
-
-- (BOOL)gcIncrementRefCountOfContainedObjects
-{
-  if (![super gcIncrementRefCountOfContainedObjects])
-    return NO;
-
-  [(id)_definitionArray gcIncrementRefCount];
-  [_inverseRelationship gcIncrementRefCount];
-  [_hiddenInverseRelationship gcIncrementRefCount];
-  [_entity gcIncrementRefCount];
-  [_destination gcIncrementRefCount];
-  [(id)_joins gcIncrementRefCount];
-  [(id)_sourceAttributes gcIncrementRefCount];
-  [(id)_destinationAttributes gcIncrementRefCount];
-  [(id)_componentRelationships gcIncrementRefCount];
-
-  [(id)_definitionArray gcIncrementRefCountOfContainedObjects];
-  [_inverseRelationship gcIncrementRefCountOfContainedObjects];
-  [_hiddenInverseRelationship gcIncrementRefCountOfContainedObjects];
-  [_entity gcIncrementRefCountOfContainedObjects];
-  [_destination gcIncrementRefCountOfContainedObjects];
-  [(id)_joins gcIncrementRefCountOfContainedObjects];
-  [(id)_sourceAttributes gcIncrementRefCountOfContainedObjects];
-  [(id)_destinationAttributes gcIncrementRefCountOfContainedObjects];
-  [(id)_componentRelationships gcIncrementRefCountOfContainedObjects];
-
-  return YES;
-}
-
 - (unsigned)hash
 {
   return [_name hash];
@@ -230,7 +154,10 @@ RCS_ID("$Id: EORelationship.m 23472 2006-09-12 19:36:24Z ayers $")
       if (destinationEntityName) //If not, this is because it's a definition
         {
           destinationEntity = [model entityNamed: destinationEntityName];
-          ASSIGN(_destination, destinationEntity);
+
+	  GDL2DestinationEntitiesRemoveRelationship(_destination, self);
+	  GDL2DestinationEntitiesAddRelationship(destinationEntity, self);
+          _destination = destinationEntity;
         }
 
       [self setToMany: [[propertyList objectForKey: @"isToMany"]
@@ -683,12 +610,12 @@ to know what to-many mean :-)  **/
     {
       int i, count = [_joins count];
 
-      _sourceAttributes = [GCMutableArray new];
+      _sourceAttributes = [NSMutableArray new];
 
       for (i = 0; i < count; i++)
         {
           EOJoin *join = [_joins objectAtIndex: i];
-          [(GCMutableArray*)_sourceAttributes addObject:
+          [(NSMutableArray*)_sourceAttributes addObject:
 			      [join sourceAttribute]];
         }
     }
@@ -703,13 +630,13 @@ to know what to-many mean :-)  **/
     {
       int i, count = [_joins count];
 
-      _destinationAttributes = [GCMutableArray new];
+      _destinationAttributes = [NSMutableArray new];
 
       for (i = 0; i < count; i++)
         {
           EOJoin *join = [_joins objectAtIndex: i];
 
-          [(GCMutableArray*)_destinationAttributes addObject:
+          [(NSMutableArray *)_destinationAttributes addObject:
 			      [join destinationAttribute]];
         }
     }
@@ -1340,7 +1267,8 @@ relationships. Nil if none" **/
       EOFLOGObjectLevelArgs(@"EORelationship", @"_definitionArray=%@", _definitionArray);
       EOFLOGObjectLevelArgs(@"EORelationship", @"[self definition]=%@", [self definition]);
 
-      DESTROY(_destination); //No ? Assign destination ?
+      GDL2DestinationEntitiesRemoveRelationship(_destination, self);
+      _destination = nil;
 
       {        
         //TODO VERIFY
@@ -1382,9 +1310,12 @@ relationships. Nil if none" **/
     {
       [self _flushCache];
       [self willChange];
+      /* FIXME docs say we should... but currently -removeRelationship 
+       * calls us, so it would cause an infinite loop */
+      // [_entity removeRelationship:self];
       [_entity _setIsEdited];
       [entity _setIsEdited];
-      ASSIGN(_entity, entity);
+      _entity = entity;
     }
 }
 
@@ -1559,15 +1490,13 @@ relationships. Nil if none" **/
                 if ([self createsMutableObjects])
                   {
                     if (!_joins)
-                      _joins = [GCMutableArray new];
+                      _joins = [NSMutableArray new];
 
-                    [(GCMutableArray *)_joins addObject: join];      
+                    [(NSMutableArray *)_joins addObject: join];      
 
                     EOFLOGObjectLevelArgs(@"EORelationship", @"XXjoins %p class%@",
 					  _joins, [_joins class]);
 
-                    //NO: will be recomputed      [(GCMutableArray *)_sourceAttributes addObject:[join sourceAttribute]];
-                    //NO: will be recomputed      [(GCMutableArray *)_destinationAttributes addObject:[join destinationAttribute]];
                   }
                 else
                   {
@@ -1575,7 +1504,7 @@ relationships. Nil if none" **/
                       _joins = RETAIN([[_joins autorelease]
 				  arrayByAddingObject: join]);
                     else
-                      _joins = RETAIN([GCArray arrayWithObject: join]);
+                      _joins = RETAIN([NSArray arrayWithObject: join]);
 
                     EOFLOGObjectLevelArgs(@"EORelationship", @"XXjoins %p class%@",
 					  _joins, [_joins class]);
@@ -1619,11 +1548,11 @@ relationships. Nil if none" **/
       [self willChange];
       if ([self createsMutableObjects])
         {
-          [(GCMutableArray *)_joins removeObject: join];
+          [(NSMutableArray *)_joins removeObject: join];
 
-          /*NO: will be recomputed      [(GCMutableArray *)_sourceAttributes
+          /*NO: will be recomputed      [(NSMutableArray *)_sourceAttributes
             removeObject:[join sourceAttribute]];
-            [(GCMutableArray *)_destinationAttributes
+            [(NSMutableArray *)_destinationAttributes
             removeObject:[join destinationAttribute]];
           */
 
@@ -1632,9 +1561,9 @@ relationships. Nil if none" **/
         }
       else
         {
-	  GCMutableArray	*ma = [_joins mutableCopy];
-	  GCArray		*a = (GCArray *)_joins;
-
+	  NSMutableArray	*ma = [_joins mutableCopy];
+	  NSArray		*a = _joins;
+	  
 	  [ma removeObject: join];
 	  _joins = ma;
           [a release];
@@ -1644,13 +1573,13 @@ relationships. Nil if none" **/
 
           /*NO: will be recomputed
             _sourceAttributes = [[_sourceAttributes autorelease] mutableCopy];
-            [(GCMutableArray *)_sourceAttributes
+            [(NSMutableArray *)_sourceAttributes
             removeObject:[join sourceAttribute]];
             _sourceAttributes = [[_sourceAttributes autorelease] copy];
       
             _destinationAttributes = [[_destinationAttributes autorelease]
             mutableCopy];
-            [(GCMutableArray *)_destinationAttributes
+            [(NSMutableArray *)_destinationAttributes
             removeObject:[join destinationAttribute]];
             _destinationAttributes = [[_destinationAttributes autorelease] copy];
           */
@@ -1810,7 +1739,7 @@ becomes "name", and "FIRST_NAME" becomes "firstName".*/
         }
       else
         {
-          _joins = [[GCArray alloc] initWithArray:[_joins autorelease] copyItems:NO];
+          _joins = [[NSArray alloc] initWithArray:[_joins autorelease] copyItems:NO];
 
           EOFLOGObjectLevelArgs(@"EORelationship", @"XXjoins %p class%@",
 		       _joins, [_joins class]);
@@ -2445,12 +2374,14 @@ dst entity primaryKeyAttributeNames
           EOAttribute *destinationAttribute = [join destinationAttribute];
           EOEntity *destinationEntity = [destinationAttribute entity];
 
-          ASSIGN(_destination, destinationEntity);
+	  GDL2DestinationEntitiesRemoveRelationship(_destination, self);
+	  GDL2DestinationEntitiesAddRelationship(destinationEntity, self);
+          _destination = destinationEntity;
         }
     }
   else
     {
-      DESTROY(_destination);
+      _destination = nil;
     }
 //_joins count
   //[self notImplemented:_cmd]; // TODO-NOW
