@@ -3,14 +3,14 @@
 
    Copyright (C) 2000-2002,2003,2004,2005 Free Software Foundation, Inc.
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: November 2001
 
-   $Revision: 23472 $
-   $Date: 2006-09-12 21:36:24 +0200 (Die, 12 Sep 2006) $
+   $Revision: 24302 $
+   $Date: 2007-01-01 12:52:38 +0100 (Mon, 01 Jän 2007) $
 
    <abstract></abstract>
 
@@ -36,7 +36,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOSQLExpression.m 23472 2006-09-12 19:36:24Z ayers $")
+RCS_ID("$Id: EOSQLExpression.m 24302 2007-01-01 11:52:38Z ayers $")
 
 #include <string.h>
 
@@ -75,7 +75,6 @@ RCS_ID("$Id: EOSQLExpression.m 23472 2006-09-12 19:36:24Z ayers $")
 #include <EOAccess/EOSQLExpression.h>
 #include <EOAccess/EOSQLQualifier.h>
 #include <EOAccess/EOExpressionArray.h>
-#include <EOAccess/EOSchemaGeneration.h>
 
 #include "EOPrivate.h"
 #include "EOEntityPriv.h"
@@ -661,7 +660,7 @@ NSString *EOBindVariableColumnKey = @"EOBindVariableColumnKey";
 */
 
 - (void)prepareSelectExpressionWithAttributes: (NSArray *)attributes
-                                         lock: (BOOL)lockFlag
+                                         lock: (BOOL)flag
                            fetchSpecification: (EOFetchSpecification *)fetchSpecification
 {
   EOQualifier *fetchQualifier = nil;
@@ -751,7 +750,7 @@ NSString *EOBindVariableColumnKey = @"EOBindVariableColumnKey";
   EOFLOGObjectLevelArgs(@"EOSQLExpression", @"tableList=%@", tableList);
 
   //Build LockClause
-  if (lockFlag)
+  if (flag)
     lockClauseString = [self lockClause];
   EOFLOGObjectLevelArgs(@"EOSQLExpression", @"lockClauseString=%@",
 			lockClauseString);
@@ -767,7 +766,7 @@ NSString *EOBindVariableColumnKey = @"EOBindVariableColumnKey";
 
   //Now Build Statement
   statement = [self assembleSelectStatementWithAttributes: attributes
-		    lock: lockFlag
+		    lock: flag
 		    qualifier: fetchQualifier
 		    fetchOrder: sortOrderings
 		    selectString: selectCommand
@@ -1855,42 +1854,42 @@ NSString *EOBindVariableColumnKey = @"EOBindVariableColumnKey";
   return sqlString;
 }
 
-- (NSString *)sqlStringForAttribute: (EOAttribute *)anAttribute
+- (NSString *)sqlStringForAttribute: (EOAttribute *)attribute
 {
   NSString *sqlString = nil;
 
   EOFLOGObjectFnStartCond(@"EOSQLExpression");
 
-  EOFLOGObjectLevelArgs(@"EOSQLExpression", @"anAttribute=%@",
-			anAttribute);
+  EOFLOGObjectLevelArgs(@"EOSQLExpression", @"attribute=%@",
+			attribute);
 
   EOFLOGObjectLevelArgs(@"EOSQLExpression", @"sFlattened=%s",
-			([anAttribute isFlattened] ? "YES" : "NO"));
+			([attribute isFlattened] ? "YES" : "NO"));
 
   EOFLOGObjectLevelArgs(@"EOSQLExpression", @"_definitionArray=%@",
-			[anAttribute _definitionArray]);
+			[attribute _definitionArray]);
 
   EOFLOGObjectLevelArgs(@"EOSQLExpression", @"_definitionArray count=%d",
-			[[anAttribute _definitionArray]count]);
+			[[attribute _definitionArray]count]);
 
-  if ([anAttribute isFlattened])
+  if ([attribute isFlattened])
     {
       sqlString = [self sqlStringForAttributePath:
-			  [anAttribute _definitionArray]];
+			  [attribute _definitionArray]];
 
       NSAssert1(sqlString, @"No sqlString for flattened attribute: %@",
-		anAttribute);
+		attribute);
     }
 //mirko:
 /*
-else if([anAttribute isDerived] == YES)
-    return [anAttribute definition];
+else if([attribute isDerived] == YES)
+    return [attribute definition];
 */
   else
     {
       if (![self useAliases])//OK
         {
-          sqlString = [anAttribute columnName];
+          sqlString = [attribute columnName];
           EOFLOGObjectLevelArgs(@"EOSQLExpression", @"sqlString=%@", sqlString);
         }
       else
@@ -1945,9 +1944,9 @@ else if([anAttribute isDerived] == YES)
 
               if (attrArray)
                 {
-                  if ([attrArray containsObject: anAttribute])
+                  if ([attrArray containsObject: attribute])
                     {
-                      NSString *columnName = [anAttribute columnName];
+                      NSString *columnName = [attribute columnName];
 
                       EOFLOGObjectLevelArgs(@"EOSQLExpression",
 					    @"columnName=%@", columnName);
@@ -1957,8 +1956,8 @@ else if([anAttribute isDerived] == YES)
                           NSEmitTODO();  //TODO what to do when there's no column name (definition only like "((firstName || ' ') || lastName)") ?
 
                           EOFLOGObjectLevelArgs(@"EOSQLExpression",
-						@"anAttribute=%@",
-						anAttribute);
+						@"attribute=%@",
+						attribute);
                           EOFLOGObjectLevelArgs(@"EOSQLExpression",
 						@"columnName=%@", columnName);
                           EOFLOGObjectLevelArgs(@"EOSQLExpression",
@@ -1969,7 +1968,7 @@ else if([anAttribute isDerived] == YES)
                         }
 
                       NSAssert1(columnName, @"No columnName for attribute %@",
-				anAttribute);
+				attribute);
 
                       sqlString = [NSString stringWithFormat: @"%@.%@",
 					    [_aliasesByRelationshipPath
@@ -1985,7 +1984,7 @@ else if([anAttribute isDerived] == YES)
 				sqlString);
         }
 
-      NSAssert1(sqlString, @"No SQLString for attribute %@", anAttribute);
+      NSAssert1(sqlString, @"No SQLString for attribute %@", attribute);
     }
 
   EOFLOGObjectLevelArgs(@"EOSQLExpression", @"sqlString=%@", sqlString);
@@ -2525,790 +2524,3 @@ All relationshipPaths in _aliasesByRelationshipPath are direct paths **/
 
 @end
 
-
-NSString *EOCreateTablesKey = @"EOCreateTablesKey";
-NSString *EODropTablesKey = @"EODropTablesKey";
-NSString *EOCreatePrimaryKeySupportKey = @"EOCreatePrimaryKeySupportKey";
-NSString *EODropPrimaryKeySupportKey = @"EODropPrimaryKeySupportKey";
-NSString *EOPrimaryKeyConstraintsKey = @"EOPrimaryKeyConstraintsKey";
-NSString *EOForeignKeyConstraintsKey = @"EOForeignKeyConstraintsKey";
-NSString *EOCreateDatabaseKey = @"EOCreateDatabaseKey";
-NSString *EODropDatabaseKey = @"EODropDatabaseKey";
-
-
-@implementation EOSQLExpression (EOSchemaGeneration)
-
-+ (NSArray *)_administrativeDatabaseStatementsForSelector:(SEL) sel
-					   forEntityGroup:(NSArray *)group
-{
-  EOEntity     *entity;
-  EOModel      *model;
-  NSDictionary *connDict;
-  NSDictionary *admDict;
-  NSArray      *stmts;
-  NSString     *notifName;
-  NSMutableDictionary  *notifDict;
-
-  entity = [group lastObject];
-  model = [entity model];
-  connDict = [model connectionDictionary];
-
-  notifDict = (id)[NSMutableDictionary dictionaryWithCapacity: 2];
-  [notifDict setObject: model forKey: EOModelKey];
-  notifName = EOAdministrativeConnectionDictionaryNeededNotification;
-  [[NSNotificationCenter defaultCenter] postNotificationName: notifName
-					object: notifDict];
-  admDict = [notifDict objectForKey: EOAdministrativeConnectionDictionaryKey];
-/* TODO: ayers 
-  if (admDict == nil && [admDict count] == 0)
-    {
-      EOAdaptor    *adaptor;
-      EOLoginPanel *panel;
-
-      adaptor = [EOAdaptor adaptorWithModel: model];
-      panel = [[adaptor class] sharedLoginPanelInstance];
-      admDict = [panel administrativeConnectionDictionaryForAdaptor: adaptor];
-    }
-*/
-  stmts = [self performSelector: sel 
-		withObject: connDict 
-		withObject: admDict];
-
-  return stmts;
-}
-
-+ (NSArray *)_dropDatabaseStatementsForEntityGroups: (NSArray *)entityGroups
-{
-  NSMutableArray *cumStmts;
-  NSArray *stmts;
-  NSArray *group;
-  unsigned i,n;
-  SEL sel;
-
-  sel = @selector(dropDatabaseStatementsForConnectionDictionary:administrativeConnectionDictionary:);
-
-  n = [entityGroups count];
-  cumStmts = [NSMutableArray arrayWithCapacity: n];
-
-  for (i=0; i<n; i++)
-    {
-      EOSQLExpression *expr;
-      unsigned j,m;
-
-      group = [entityGroups objectAtIndex: i];
-      stmts = [self _administrativeDatabaseStatementsForSelector: sel
-		    forEntityGroup: group];
-      for (j=0, m=[stmts count]; j<m; j++)
-	{
-	  NSArray  *rawStmts;
-	  NSString *stmt;
-
-	  rawStmts = [cumStmts valueForKey:@"statement"];
-	  expr = [stmts objectAtIndex: j];
-	  stmt = [expr statement];
-
-	  if ([rawStmts containsObject: stmt] == NO)
-	    {
-	      [cumStmts addObject: expr];
-	    }
-	}
-    }
-
-  return [NSArray arrayWithArray: cumStmts];
-}
-
-+ (NSArray *)_createDatabaseStatementsForEntityGroups: (NSArray *)entityGroups
-{
-  NSMutableArray *cumStmts;
-  NSArray *stmts;
-  NSArray *group;
-  unsigned i,n;
-  SEL sel;
-
-  sel = @selector(createDatabaseStatementsForConnectionDictionary:administrativeConnectionDictionary:);
-
-  n = [entityGroups count];
-  cumStmts = [NSMutableArray arrayWithCapacity: n];
-
-  for (i=0; i<n; i++)
-    {
-      EOSQLExpression *expr;
-      unsigned j,m;
-
-      group = [entityGroups objectAtIndex: i];
-      stmts = [self _administrativeDatabaseStatementsForSelector: sel
-		    forEntityGroup: group];
-
-      for (j=0, m=[stmts count]; j<m; j++)
-	{
-	  NSArray  *rawStmts;
-	  NSString *stmt;
-
-	  rawStmts = [cumStmts valueForKey:@"statement"];
-	  expr = [stmts objectAtIndex: j];
-	  stmt = [expr statement];
-
-	  if ([rawStmts containsObject: stmt] == NO)
-	    {
-	      [cumStmts addObject: expr];
-	    }
-	}
-    }
-
-  return [NSArray arrayWithArray: cumStmts];
-}
-
-+ (NSArray *)foreignKeyConstraintStatementsForRelationship: (EORelationship *)relationship
-{
-  NSMutableArray *array, *sourceColumns, *destColumns;
-  EOSQLExpression *sqlExpression;
-  EOEntity *entity;
-  NSEnumerator *joinEnum;
-  EOJoin *join;
-  unsigned num;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  array = [NSMutableArray arrayWithCapacity: 1];
-
-  if ([[relationship entity] model]
-      != [[relationship destinationEntity] model])
-    {
-      EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-      return array;
-    }
-
-  if ([relationship isToMany] == YES
-      || ([relationship inverseRelationship] != nil
-	  && [[relationship inverseRelationship] isToMany] == NO))
-    {
-      EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-      return array;
-    }
-
-  entity = [relationship entity];
-  sqlExpression = [self sqlExpressionWithEntity: entity];
-
-  num = [[relationship joins] count];
-
-  sourceColumns = [NSMutableArray arrayWithCapacity: num];
-  destColumns   = [NSMutableArray arrayWithCapacity: num];
-
-  joinEnum = [[relationship joins] objectEnumerator];
-  while ((join = [joinEnum nextObject]))
-    {
-      [sourceColumns addObject: [join sourceAttribute]];
-      [destColumns   addObject: [join destinationAttribute]];
-    }
-
-  [sqlExpression prepareConstraintStatementForRelationship: relationship
-		 sourceColumns: sourceColumns
-		 destinationColumns: destColumns];
-
-  [array addObject: sqlExpression];
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return array;
-}
-
-+ (NSArray *)foreignKeyConstraintStatementsForEntityGroup:(NSArray *)entityGroup
-{
-  NSMutableArray *sqlExps;
-  EORelationship *rel;
-  EOEntity       *entity;
-  EOEntity       *parentEntity;
-  unsigned       i,j,n,m;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  sqlExps = [NSMutableArray array];
-
-  for (i=0, n=[entityGroup count]; i<n; i++)
-    {
-      NSArray *rels;
-
-      entity = [entityGroup objectAtIndex: i];
-      parentEntity = [entity parentEntity];
-      rels = [entity relationships];
-
-      for (j=0, m=[rels count]; parentEntity == nil && j<m; j++)
-	{
-	  NSArray *stmts;
-
-	  rel = [rels objectAtIndex: j];
-	  stmts =[self foreignKeyConstraintStatementsForRelationship: rel];
-	  [sqlExps addObjectsFromArray: stmts];
-	}
-    }
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return sqlExps;
-}
-
-+ (NSArray *)foreignKeyConstraintStatementsForEntityGroups: (NSArray *)entityGroups
-{
-  NSMutableArray *array;
-  NSEnumerator   *groupsEnum;
-  NSArray        *group;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  array = [NSMutableArray arrayWithCapacity: [entityGroups count]];
-
-  groupsEnum = [entityGroups objectEnumerator];
-  while ((group = [groupsEnum nextObject]))
-    {
-      NSArray *stmts;
-
-      stmts = [self foreignKeyConstraintStatementsForEntityGroup: group];
-      [array addObjectsFromArray: stmts];
-    }
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return array;
-}
-
-// default implementation verifies that relationship joins on foreign key
-// of destination and calls
-// prepareConstraintStatementForRelationship:sourceColumns:destinationColumns:
-
-+ (NSArray *)createTableStatementsForEntityGroup: (NSArray *)entityGroup
-{
-  EOSQLExpression *sqlExp;
-  NSEnumerator *entityEnum, *attrEnum;
-  EOAttribute *attr;
-  EOEntity *entity;
-  NSString *tableName;
-  NSString *stmt;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  sqlExp = [self sqlExpressionWithEntity:[entityGroup objectAtIndex: 0]];
-
-  entityEnum = [entityGroup objectEnumerator];
-  while ((entity = [entityEnum nextObject]))
-    {
-      attrEnum = [[entity attributes] objectEnumerator];
-
-      while ((attr = [attrEnum nextObject]))
-	[sqlExp addCreateClauseForAttribute: attr];
-    }
-
-  entity = [entityGroup objectAtIndex: 0];
-  tableName = [entity externalName];
-  tableName = [sqlExp sqlStringForSchemaObjectName: tableName];
-
-  stmt = [NSString stringWithFormat: @"CREATE TABLE %@ (%@)",
-		   tableName,
-		   [sqlExp listString]];
-  [sqlExp setStatement: stmt];
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return [NSArray arrayWithObject: sqlExp];
-}
-
-+ (NSArray *)dropTableStatementsForEntityGroup:(NSArray *)entityGroup
-{
-  NSArray *newArray;
-  NSString *tableName;
-  EOEntity *entity;
-  NSString *stmt;
-  EOSQLExpression *sqlExp;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  entity = [entityGroup objectAtIndex: 0];
-  sqlExp = [self sqlExpressionWithEntity: entity];
-  tableName = [entity externalName];
-  tableName = [sqlExp sqlStringForSchemaObjectName: tableName];
-
-  stmt = [NSString stringWithFormat: @"DROP TABLE %@", tableName];
-  [sqlExp setStatement: stmt];
-  newArray = [NSArray arrayWithObject: sqlExp];
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return newArray;
-}
-
-+ (NSArray *)primaryKeyConstraintStatementsForEntityGroup:(NSArray *)entityGroup
-{
-  EOSQLExpression *sqlExp;
-  NSMutableString *listString;
-  NSEnumerator    *attrEnum;
-  EOAttribute     *attr;
-  EOEntity        *entity;
-  NSString        *tableName;
-  NSString        *stmt;
-  BOOL             first = YES;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  entity = [entityGroup objectAtIndex: 0];
-  listString = [NSMutableString stringWithCapacity: 30];
-
-  attrEnum = [[entity primaryKeyAttributes] objectEnumerator];
-  while ((attr = [attrEnum nextObject]))
-    {
-      NSString *columnName = [attr columnName];
-
-      if (!columnName || ![columnName length])
-	continue;
-
-      if (first == NO)
-	[listString appendString: @", "];
-
-      [listString appendString: columnName];
-      first = NO;
-    }
-
-  if (first == YES)
-    {
-      EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-      return [NSArray array];
-    }
-
-  sqlExp = [self sqlExpressionWithEntity:[entityGroup objectAtIndex: 0]];
-  tableName = [entity externalName];
-  tableName = [sqlExp sqlStringForSchemaObjectName: tableName];
-
-  stmt = [NSString stringWithFormat: @"ALTER TABLE %@ ADD PRIMARY KEY (%@)",
-		   tableName, listString];
-  [sqlExp setStatement: stmt];
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return [NSArray arrayWithObject: sqlExp];
-}
-
-+ (NSArray *)primaryKeySupportStatementsForEntityGroup: (NSArray *)entityGroup
-{
-  NSArray *newArray;
-  NSString *seqName;
-  EOEntity *entity;
-  NSString *pkRootName;
-  NSString *stmt;
-  EOSQLExpression *sqlExp;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  entity = [entityGroup objectAtIndex: 0];
-  pkRootName = [entity primaryKeyRootName];
-  seqName = [NSString stringWithFormat: @"%@_SEQ", pkRootName];
-
-  sqlExp = [self sqlExpressionWithEntity: nil];
-  seqName = [sqlExp sqlStringForSchemaObjectName: seqName];
-
-  stmt = [NSString stringWithFormat: @"CREATE SEQUENCE %@", seqName];
-  [sqlExp setStatement: stmt];
-  newArray = [NSArray arrayWithObject: sqlExp];
-                                      
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return newArray;
-}
-
-+ (NSArray *)dropPrimaryKeySupportStatementsForEntityGroup: (NSArray *)entityGroup
-{
-  NSArray *newArray;
-  NSString *seqName;
-  EOEntity *entity;
-  NSString *pkRootName;
-  NSString *stmt;
-  EOSQLExpression *sqlExp;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  entity = [entityGroup objectAtIndex: 0];
-  pkRootName = [entity primaryKeyRootName];
-  seqName = [NSString stringWithFormat: @"%@_SEQ", pkRootName];
-
-  sqlExp = [self sqlExpressionWithEntity: nil];
-  seqName = [sqlExp sqlStringForSchemaObjectName: seqName];
-
-  stmt = [NSString stringWithFormat: @"DROP SEQUENCE %@", seqName];
-  [sqlExp setStatement: stmt];
-  newArray = [NSArray arrayWithObject: sqlExp];
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return newArray;
-}
-
-+ (NSArray *)createTableStatementsForEntityGroups: (NSArray *)entityGroups
-{
-  NSMutableArray *array;
-  NSEnumerator   *groupsEnum;
-  NSArray        *group;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  array = [NSMutableArray arrayWithCapacity: [entityGroups count]];
-
-  groupsEnum = [entityGroups objectEnumerator];
-  while ((group = [groupsEnum nextObject]))
-    {
-      [array addObjectsFromArray:
-	       [self createTableStatementsForEntityGroup: group]];
-    }
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return array;
-}
-
-+ (NSArray *)dropTableStatementsForEntityGroups: (NSArray *)entityGroups
-{
-  NSMutableArray *array;
-  NSEnumerator   *groupsEnum;
-  NSArray        *group;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  array = [NSMutableArray arrayWithCapacity: [entityGroups count]];
-
-  groupsEnum = [entityGroups objectEnumerator];
-  while ((group = [groupsEnum nextObject]))
-    {
-      [array addObjectsFromArray:
-	       [self dropTableStatementsForEntityGroup: group]];
-    }
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return array;
-}
-
-+ (NSArray *)primaryKeyConstraintStatementsForEntityGroups: (NSArray *)entityGroups
-{
-  NSMutableArray *array;
-  NSEnumerator   *groupsEnum;
-  NSArray        *group;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  array = [NSMutableArray arrayWithCapacity: [entityGroups count]];
-
-  groupsEnum = [entityGroups objectEnumerator];
-  while ((group = [groupsEnum nextObject]))
-    {
-      [array addObjectsFromArray:
-	       [self primaryKeyConstraintStatementsForEntityGroup: group]];
-    }
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return array;
-}
-
-+ (NSArray *)primaryKeySupportStatementsForEntityGroups: (NSArray *)entityGroups
-{
-  NSMutableArray *array;
-  NSEnumerator   *groupsEnum;
-  NSArray        *group;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  array = [NSMutableArray arrayWithCapacity: [entityGroups count]];
-
-  groupsEnum = [entityGroups objectEnumerator];
-  while ((group = [groupsEnum nextObject]))
-    {
-      [array addObjectsFromArray:
-	       [self primaryKeySupportStatementsForEntityGroup: group]];
-    }
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return array;
-}
-
-+ (NSArray *)dropPrimaryKeySupportStatementsForEntityGroups: (NSArray *)entityGroups
-{
-  NSMutableArray *array;
-  NSEnumerator   *groupsEnum;
-  NSArray        *group;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  array = [NSMutableArray arrayWithCapacity: [entityGroups count]];
-
-  groupsEnum = [entityGroups objectEnumerator];
-  while ((group = [groupsEnum nextObject]))
-    {
-      [array addObjectsFromArray:
-	       [self dropPrimaryKeySupportStatementsForEntityGroup: group]];
-    }
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return array;
-}
-
-+ (void)appendExpression: (EOSQLExpression *)expression
-		toScript: (NSMutableString *)script
-{
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-  
-  [script appendFormat:@"%@;\n", [expression statement]];
-  
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-}
-
-
-+ (NSString *)schemaCreationScriptForEntities: (NSArray *)entities
-				      options: (NSDictionary *)options
-{
-  NSMutableString *script = [NSMutableString stringWithCapacity:50];
-  NSEnumerator    *arrayEnum;
-  EOSQLExpression *sqlExp;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  arrayEnum = [[self schemaCreationStatementsForEntities: entities
-		     options: options] objectEnumerator];
-
-  while ((sqlExp = [arrayEnum nextObject]))
-    [self appendExpression: sqlExp toScript: script];
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return script;
-}
-
-struct _schema
-{
-  NSString *key;
-  NSString *value;
-  SEL       selector;
-};
-
-+ (NSArray *)schemaCreationStatementsForEntities: (NSArray *)entities
-					 options: (NSDictionary *)options
-{
-  NSMutableArray *array = [NSMutableArray arrayWithCapacity: 5];
-  NSMutableArray *groups = [NSMutableArray arrayWithCapacity: 5];
-  NSMutableArray *group;
-  NSString       *externalName;
-  EOEntity       *entity;
-  int             i, h, count;
-  struct _schema  defaults[] = {
-    {EODropPrimaryKeySupportKey  , @"YES",
-     @selector(dropPrimaryKeySupportStatementsForEntityGroups:)},
-    {EODropTablesKey             , @"YES",
-     @selector(dropTableStatementsForEntityGroups:)},
-    {EODropDatabaseKey , @"NO",
-     @selector(_dropDatabaseStatementsForEntityGroups:)},
-    {EOCreateDatabaseKey , @"NO",
-     @selector(_createDatabaseStatementsForEntityGroups:)},
-    {EOCreateTablesKey           , @"YES",
-     @selector(createTableStatementsForEntityGroups:)},
-    {EOCreatePrimaryKeySupportKey, @"YES",
-     @selector(primaryKeySupportStatementsForEntityGroups:)},
-    {EOPrimaryKeyConstraintsKey   , @"YES",
-     @selector(primaryKeyConstraintStatementsForEntityGroups:)},
-    {EOForeignKeyConstraintsKey  , @"NO",
-     @selector(foreignKeyConstraintStatementsForEntityGroups:)},
-    {nil, nil},
-  }; // Order is important!
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  count = [entities count];
-
-  for (i = 0; i < count; i++)
-    {
-      entity = [entities objectAtIndex: i];
-      externalName = [entity externalName];
-
-      group = [NSMutableArray arrayWithCapacity: 1];
-      [groups addObject: group];
-      [group addObject: entity];
-
-      for (h = i + 1; h < count; h++)
-	{
-	  if ([[[entities objectAtIndex: h] externalName]
-		isEqual: externalName])
-	    [group addObject: [entities objectAtIndex: h]];
-	}
-    }
-
-  for (i = 0; defaults[i].key != nil; i++)
-    {
-      NSString *value;
-
-      value = [options objectForKey: defaults[i].key];
-
-      if (!value)
-	value = defaults[i].value;
-
-      if ([value isEqual: @"YES"] == YES)
-	{
-	  NSArray *stmts;
-	  stmts = [self performSelector: defaults[i].selector
-			withObject: groups];
-	  [array addObjectsFromArray: stmts];
-	}
-    }
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-
-  return array;
-}
-
-- (NSString *)columnTypeStringForAttribute:(EOAttribute *)attribute
-{
-  NSString *extType = [attribute externalType];
-  int precision = [attribute precision];
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  if (precision)
-    {
-      EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-      return [NSString stringWithFormat:@"%@(%d, %d)", extType, precision,
-		       [attribute scale]];
-    }
-  else if ([attribute width])
-    {
-      EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-      return [NSString stringWithFormat: @"%@(%d)", 
-		       extType, [attribute width]];
-    }
-  else
-    {
-      EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-      return [NSString stringWithFormat: @"%@", extType];
-    }
-}
-
-- (NSString *)allowsNullClauseForConstraint: (BOOL)allowsNull
-{
-  if (allowsNull == NO)
-    return @"NOT NULL";
-
-  return nil;
-}
-
-- (void)addCreateClauseForAttribute: (EOAttribute *)attribute
-{
-  NSString *columnType;
-  NSString *allowsNull;
-  NSString *str;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  columnType = [self columnTypeStringForAttribute: attribute];
-  allowsNull = [self allowsNullClauseForConstraint: [attribute allowsNull]];
-
-  if (allowsNull)
-    str = [NSString stringWithFormat: @"%@ %@ %@", [attribute columnName],
-		    columnType, allowsNull];
-  else
-    str = [NSString stringWithFormat: @"%@ %@", [attribute columnName],
-		    columnType];
-
-  [self appendItem:str toListString: /*_listString*/[self listString]]; // Else no chance to get inited (lazy)
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-}
-
-- (void)prepareConstraintStatementForRelationship: (EORelationship *)relationship
-				    sourceColumns: (NSArray *)sourceColumns
-			       destinationColumns: (NSArray *)destinationColumns
-{
-  NSMutableString *sourceString, *destinationString;
-  NSEnumerator    *attrEnum;
-  EOAttribute     *attr;
-  NSString        *name, *str, *tableName, *relTableName;
-  BOOL             first = YES;
-
-  EOFLOGClassFnStartOrCond(@"EOSQLExpression");
-
-  name = [NSString stringWithFormat: @"%@_%@_FK", [_entity externalName],
-		   [relationship name]];
-
-  sourceString = [NSMutableString stringWithCapacity: 30];
-
-  attrEnum = [sourceColumns objectEnumerator];
-  while ((attr = [attrEnum nextObject]))
-    {
-      NSString *columnName = [attr columnName];
-
-      if (!columnName || ![columnName length])
-	continue;
-
-      if (first == NO)
-	[sourceString appendString: @", "];
-
-      [sourceString appendString: columnName];
-      first = NO;
-    }
-
-  first = YES;
-  destinationString = [NSMutableString stringWithCapacity: 30];
-
-  attrEnum = [destinationColumns objectEnumerator];
-  while ((attr = [attrEnum nextObject]))
-    {
-      NSString *columnName = [attr columnName];
-
-      if (!columnName || ![columnName length])
-	continue;
-
-      if (first == NO)
-	[destinationString appendString: @", "];
-
-      [destinationString appendString: columnName];
-      first = NO;
-    }
-
-  tableName = [_entity externalName];
-  tableName = [self sqlStringForSchemaObjectName: tableName];
-
-  relTableName = [[relationship destinationEntity] externalName];
-  relTableName = [self sqlStringForSchemaObjectName: relTableName];
-
-  str = [NSString stringWithFormat: @"ALTER TABLE %@ ADD CONSTRAINT %@ "
-		  @"FOREIGN KEY (%@) REFERENCES %@ (%@)",
-		  tableName,
-		  name,
-		  sourceString,
-		  relTableName,
-		  destinationString];
-
-  ASSIGN(_statement, str);
-
-  EOFLOGClassFnStopOrCond(@"EOSQLExpression");
-}
-
-// Assembles an adaptor specific constraint statement for relationship.
-
-+ (NSArray *)createDatabaseStatementsForConnectionDictionary: (NSDictionary *)connectionDictionary
-			  administrativeConnectionDictionary: (NSDictionary *)administrativeConnectionDictionary
-{
-  [self subclassResponsibility: _cmd];
-  return nil;
-}
-
-+ (NSArray *)dropDatabaseStatementsForConnectionDictionary: (NSDictionary *)connectionDictionary
-			administrativeConnectionDictionary: (NSDictionary *)administrativeConnectionDictionary
-{
-  [self subclassResponsibility: _cmd];
-  return nil;
-}
-
-+ (EOSQLExpression *)selectStatementForContainerOptions
-{
-  [self notImplemented: _cmd];
-  return nil;
-}
-
-@end
