@@ -6,8 +6,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: Sep 2000
 
-   $Revision: 23472 $
-   $Date: 2006-09-12 21:36:24 +0200 (Die, 12 Sep 2006) $
+   $Revision: 24302 $
+   $Date: 2007-01-01 12:52:38 +0100 (Mon, 01 Jän 2007) $
 
    <abstract></abstract>
 
@@ -33,7 +33,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOUtilities.m 23472 2006-09-12 19:36:24Z ayers $")
+RCS_ID("$Id: EOUtilities.m 24302 2007-01-01 11:52:38Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSString.h>
@@ -758,7 +758,7 @@ NSString *NSObjectNotAvailableException = @"NSObjectNotAvailableException";
                entityNamed: entityName];
 }
 
-- (EODatabaseContext *)databaseContextForModelNamed: (NSString *)name;
+- (EODatabaseContext *)databaseContextForModelNamed: (NSString *)name
 {
   EOModelGroup *modelGroup;
   EOModel *model;
@@ -816,7 +816,7 @@ connectionDictionaryOverrides: (NSDictionary *)overrides
   return object;
 }
 
-- (NSDictionary *)primaryKeyForObject: (id)object;
+- (NSDictionary *)primaryKeyForObject: (id)object
 {
   EOKeyGlobalID *gid;
   EOEntity *entity;
@@ -1094,53 +1094,3 @@ connectionDictionaryOverrides: (NSDictionary *)overrides
 
 @end
 
-
-@implementation EOObjectStoreCoordinator (EOModelGroup)
-
-- (id)modelGroup
-{
-  //Seems OK
-  EOModelGroup *modelGroup;
-  NSDictionary *userInfo;
-
-  EOFLOGObjectFnStart();
-
-  userInfo = [self userInfo];
-  modelGroup = [userInfo objectForKey: @"EOModelGroup"];
-
-  if (!modelGroup)
-    {
-      modelGroup = [EOModelGroup defaultGroup];
-      [self setModelGroup: modelGroup];
-    }
-
-  EOFLOGObjectFnStop();
-
-  return modelGroup;
-}
-
-- (void)setModelGroup: (EOModelGroup *)modelGroup
-{
-  NSMutableDictionary *userInfo;
-
-  EOFLOGObjectFnStart();
-
-  userInfo = (NSMutableDictionary *)[self userInfo];
-
-  if (userInfo)
-    [userInfo setObject: modelGroup
-              forKey: @"EOModelGroup"];
-  else
-    {
-      userInfo = (id)[NSMutableDictionary dictionary];
-
-      [userInfo setObject: modelGroup
-                forKey: @"EOModelGroup"];
-      [self setUserInfo: userInfo];
-    }
-
-  EOFLOGObjectFnStop();
-}
-
-@end
-
