@@ -1,13 +1,13 @@
 /**
    EOCheapArray.m <title>EOCheapCopyArray Classes</title>
 
-   Copyright (C) 2000-2003 Free Software Foundation, Inc.
+   Copyright (C) 2000-2002,2003,2004,2005 Free Software Foundation, Inc.
 
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: Sep 2000
 
-   $Revision: 1.12 $
-   $Date: 2004/03/19 16:41:19 $
+   $Revision: 23472 $
+   $Date: 2006-09-12 21:36:24 +0200 (Die, 12 Sep 2006) $
 
    <abstract></abstract>
 
@@ -27,13 +27,13 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
    </license>
 **/
 
 #include "config.h"
 
-RCS_ID("$Id: EOCheapArray.m,v 1.12 2004/03/19 16:41:19 ayers Exp $")
+RCS_ID("$Id: EOCheapArray.m 23472 2006-09-12 19:36:24Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSArray.h>
@@ -66,7 +66,7 @@ RCS_ID("$Id: EOCheapArray.m,v 1.12 2004/03/19 16:41:19 ayers Exp $")
 
   return [super init];
 };
-- (id) initWithArray: (id)array
+- (id)initWithArray: (NSArray *)array
 {
 #ifdef DEBUG
   NSDebugFLog(@"initWithArray EOCheapCopyArray %p", 
@@ -138,6 +138,8 @@ RCS_ID("$Id: EOCheapArray.m,v 1.12 2004/03/19 16:41:19 ayers Exp $")
     }
 
   NSDeallocateObject(self);
+  /* Suppress compiler warning.  */
+  if (0) [super dealloc];
 
 #ifdef DEBUG
   NSDebugFLog(@"Stop Dealloc EOCheapCopyArray %p. %@",
@@ -243,12 +245,11 @@ RCS_ID("$Id: EOCheapArray.m,v 1.12 2004/03/19 16:41:19 ayers Exp $")
   return self;
 }
 
-- (id) initWithArray:(NSArray*)array
+- (id)initWithArray: (NSArray *)array
 {
-  _grow_factor = 5;
-
   if ((self = [super initWithArray: array]))
     {
+      _grow_factor = 5;
     }
 
   return self;
@@ -274,6 +275,8 @@ RCS_ID("$Id: EOCheapArray.m,v 1.12 2004/03/19 16:41:19 ayers Exp $")
 
   DESTROY(_immutableCopy);
   NSDeallocateObject(self);
+  /* Suppress compiler warning.  */
+  if (0) [super dealloc];
 
 #ifdef DEBUG
   NSDebugFLog(@"Stop Dealloc EOCheapCopyMutableArray %p. %@",
@@ -281,7 +284,7 @@ RCS_ID("$Id: EOCheapArray.m,v 1.12 2004/03/19 16:41:19 ayers Exp $")
 #endif
 }
 
-- (id) shallowCopy
+- (NSArray *)shallowCopy
 {
 #ifdef DEBUG
   NSDebugFLog(@"Start shallowCopy EOCheapCopyMutableArray %p. %@ immutableCopy=%p",
