@@ -4,14 +4,14 @@
    Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 
    Free Software Foundation, Inc.
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: November 2001
 
-   $Revision: 21669 $
-   $Date: 2005-08-23 16:40:44 +0200 (Die, 23 Aug 2005) $
+   $Revision: 24297 $
+   $Date: 2006-12-30 18:41:02 +0100 (Sam, 30 Dez 2006) $
 
    <abstract></abstract>
 
@@ -37,7 +37,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOClassDescription.m 21669 2005-08-23 14:40:44Z mguesdon $")
+RCS_ID("$Id: EOClassDescription.m 24297 2006-12-30 17:41:02Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSString.h>
@@ -76,7 +76,7 @@ RCS_ID("$Id: EOClassDescription.m 21669 2005-08-23 14:40:44Z mguesdon $")
 // NOTE: (stephane@sente.ch) Should we subclass NSClassDescription?
 
 /*
-   d.ayers@inode.at:  Yes, once we wish to support code written for
+   ayers@fsfe.org:  Yes, once we wish to support code written for
    for EOF > WO4.5. No, for now because we don't have direct access
    to the NSMapTable of base/Foundation so we would loose efficiency
    and gain no real benefit.
@@ -86,8 +86,6 @@ RCS_ID("$Id: EOClassDescription.m 21669 2005-08-23 14:40:44Z mguesdon $")
 +(id)defaultGroup;
 @end
 
-@implementation EOClassDescription
-
 NSString *EOClassDescriptionNeededNotification 
       = @"EOClassDescriptionNeededNotification";
 
@@ -111,6 +109,8 @@ static NSMapTable *classDescriptionForClass = NULL;
 static id classDelegate = nil;
 static NSRecursiveLock *local_lock = nil;
 
+@implementation EOClassDescription
+
 + (void) initialize
 {
   static BOOL initialized=NO;
@@ -303,17 +303,18 @@ static NSRecursiveLock *local_lock = nil;
   EOFLOGObjectFnStop();
 
   return dictionary;
-};
-
-- (void)awakeObject: (id)object
-fromFetchInEditingContext: (EOEditingContext *)anEditingContext
-{
-  //OK
-  //nothing to do
 }
 
 - (void)awakeObject: (id)object
-fromInsertionInEditingContext: (EOEditingContext *)anEditingContext
+fromFetchInEditingContext: (EOEditingContext *)editingContext
+{
+  //OK
+  //nothing to do
+  return;
+}
+
+- (void)awakeObject: (id)object
+fromInsertionInEditingContext: (EOEditingContext *)editingContext
 {
   //Near OK
   NSArray *toManyRelationshipKeys = nil;
@@ -357,7 +358,7 @@ fromInsertionInEditingContext: (EOEditingContext *)anEditingContext
   return nil;
 }
 
-- (id)createInstanceWithEditingContext: (EOEditingContext *)anEditingContext
+- (id)createInstanceWithEditingContext: (EOEditingContext *)editingContext
                               globalID: (EOGlobalID *)globalID
                                   zone: (NSZone *)zone
 {
@@ -440,7 +441,7 @@ fromInsertionInEditingContext: (EOEditingContext *)anEditingContext
 }
 
 - (void)propagateDeleteForObject: (id)object
-                  editingContext: (EOEditingContext *)context
+                  editingContext: (EOEditingContext *)editingContext
 {
   NSArray *toRelArray;
   NSEnumerator *toRelEnum;
@@ -478,9 +479,12 @@ fromInsertionInEditingContext: (EOEditingContext *)anEditingContext
           NSDebugMLLog(@"gsdb", @"ToOne key=%@", key);
           
           if (classDelegate)
-            shouldPropagate = [classDelegate shouldPropagateDeleteForObject: object
-                                             inEditingContext: context
-                                             forRelationshipKey: key];
+	    {
+	      shouldPropagate 
+		= [classDelegate shouldPropagateDeleteForObject: object
+				 inEditingContext: editingContext
+				 forRelationshipKey: key];
+	    }
           
           NSDebugMLLog(@"gsdb", @"ToOne key=%@ shouldPropagate=%s", key,
                        (shouldPropagate ? "YES" : "NO"));
@@ -523,8 +527,8 @@ fromInsertionInEditingContext: (EOEditingContext *)anEditingContext
                       EOFLOGObjectLevel(@"gsdb", @"EODeleteRuleCascade");
                       [object removeObject: destination
                               fromBothSidesOfRelationshipWithKey: key];
-                      [context deleteObject: destination];
-                      [destination propagateDeleteWithEditingContext: context];
+                      [editingContext deleteObject: destination];
+                      [destination propagateDeleteWithEditingContext: editingContext];
                       break;
                       
                     case EODeleteRuleDeny:
@@ -554,9 +558,12 @@ fromInsertionInEditingContext: (EOEditingContext *)anEditingContext
           NSDebugMLLog(@"gsdb", @"ToMany key=%@", key);
 
           if (classDelegate)
-            shouldPropagate = [classDelegate shouldPropagateDeleteForObject: object
-                                             inEditingContext: context
-                                             forRelationshipKey: key];
+	    {
+	      shouldPropagate 
+		= [classDelegate shouldPropagateDeleteForObject: object
+				 inEditingContext: editingContext
+				 forRelationshipKey: key];
+	    }
           NSDebugMLLog(@"gsdb", @"ToMany key=%@ shouldPropagate=%s", key,
                        (shouldPropagate ? "YES" : "NO"));
 
@@ -612,8 +619,8 @@ fromInsertionInEditingContext: (EOEditingContext *)anEditingContext
 
                       [object removeObject: destination
                               fromBothSidesOfRelationshipWithKey: key];
-                      [context deleteObject: destination];
-                      [destination propagateDeleteWithEditingContext: context];
+                      [editingContext deleteObject: destination];
+                      [destination propagateDeleteWithEditingContext: editingContext];
                     }
                   NSDebugMLLog(@"gsdb", @"toManyArray %p=%@",
                                toManyArray, toManyArray);
@@ -661,17 +668,17 @@ fromInsertionInEditingContext: (EOEditingContext *)anEditingContext
   return nil;
 }
 
-- (EORelationship *)anyRelationshipNamed:(NSString *)relationshipNamed
+- (EORelationship *)anyRelationshipNamed:(NSString *)relationshipName
 {
   return nil;
 }
 
-- (NSString *)userPresentableDescriptionForObject:(id)anObject
+- (NSString *)userPresentableDescriptionForObject:(id)object
 {
   NSArray *attrArray = [self attributeKeys];
   NSEnumerator *attrEnum = [attrArray objectEnumerator];
-  NSMutableString *values = [NSMutableString stringWithCapacity:
-					       4 * [attrArray count]];
+  NSMutableString *values 
+    = [NSMutableString stringWithCapacity: 4 * [attrArray count]];
   NSString *key;
   BOOL init = YES;
 
@@ -729,9 +736,9 @@ fromInsertionInEditingContext: (EOEditingContext *)anEditingContext
 
 @implementation NSObject (EOInitialization)
 
-- (id)initWithEditingContext: (EOEditingContext *)ec
-	    classDescription: (EOClassDescription *)classDesc
-		    globalID: (EOGlobalID *)globalID;
+- (id)initWithEditingContext: (EOEditingContext *)editingContext
+	    classDescription: (EOClassDescription *)classDescription
+		    globalID: (EOGlobalID *)globalID
 {
   return [self init];
 }
@@ -1870,7 +1877,7 @@ fromBothSidesOfRelationshipWithKey: (NSString *)key
 @implementation NSObject (EOClassDescriptionClassDelegate)
 
 - (BOOL)shouldPropagateDeleteForObject: (id)object
-                      inEditingContext: (EOEditingContext *)ec
+                      inEditingContext: (EOEditingContext *)editingContext
                     forRelationshipKey: (NSString *)key
 {
   return YES;
@@ -2007,13 +2014,3 @@ fromBothSidesOfRelationshipWithKey: (NSString *)key
 
 @end
 
-@implementation NSObject (_EOEditingContext)
-
-- (EOEditingContext*)editingContext
-{
-  return [EOObserverCenter observerForObject: self
-                           ofClass: [EOEditingContext class]];
-}
-
-@end
-
