@@ -3,11 +3,11 @@
 
    Copyright (C) 2000-2002,2003,2004,2005 Free Software Foundation, Inc.
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: July 2000
 
-   $Revision: 21645 $
-   $Date: 2005-08-17 10:07:57 +0200 (Mit, 17 Aug 2005) $
+   $Revision: 24297 $
+   $Date: 2006-12-30 18:41:02 +0100 (Sam, 30 Dez 2006) $
 
    <abstract></abstract>
 
@@ -33,7 +33,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EODataSource.m 21645 2005-08-17 08:07:57Z ayers $")
+RCS_ID("$Id: EODataSource.m 24297 2006-12-30 17:41:02Z ayers $")
 
 
 #ifndef GNUSTEP
@@ -120,6 +120,7 @@ RCS_ID("$Id: EODataSource.m 21645 2005-08-17 08:07:57Z ayers $")
 
 - (void)setQualifierBindings: (NSDictionary *)bindings
 {
+  return;
 }
 
 - (NSDictionary *)qualifierBindings
