@@ -1,6 +1,6 @@
 /* -*-objc-*-
    debug.h - debug
-   Copyright (C) 1999, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
    
    Written by:	Manuel Guesdon <mguesdon@sbuilders.com>
    Date: 	Jan 1999
@@ -18,11 +18,12 @@
    Library General Public License for more details.
    
    You should have received a copy of the GNU Library General Public
-   License along with this library; if not, write to the Free
-   Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   License along with this library; see the file COPYING.LIB.
+   If not, write to the Free Software Foundation,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
-// $Id: EODebug.h,v 1.8 2004/04/17 11:30:47 ayers Exp $
+// $Id: EODebug.h 21645 2005-08-17 08:07:57Z ayers $
 
 #ifndef _EODebug_h__
 #define _EODebug_h__
