@@ -1,12 +1,12 @@
 /* EODebug.m - <title>debug</title>
 
-   Copyright (C) 1999-2003 Free Software Foundation, Inc.
+   Copyright (C) 1999-2002,2003,2004,2005 Free Software Foundation, Inc.
    
    Written by:	Manuel Guesdon <mguesdon@orange-concept.com>
    Date: 		Jan 1999
 
-   $Revision: 1.11 $
-   $Date: 2004/03/19 16:41:20 $
+   $Revision: 21645 $
+   $Date: 2005-08-17 10:07:57 +0200 (Mit, 17 Aug 2005) $
 
    <abstract></abstract>
 
@@ -24,14 +24,15 @@
    Library General Public License for more details.
    
    You should have received a copy of the GNU Library General Public
-   License along with this library; if not, write to the Free
-   Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   License along with this library; see the file COPYING.LIB.
+   If not, write to the Free Software Foundation,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
    </license>
 **/
 
 #include "config.h"
 
-RCS_ID("$Id: EODebug.m,v 1.11 2004/03/19 16:41:20 ayers Exp $")
+RCS_ID("$Id: EODebug.m 21645 2005-08-17 08:07:57Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSThread.h>
@@ -278,8 +279,10 @@ TypeToNSString(const char* _type)
 	case _C_UINT:     return @"unsigned int";
 	case _C_LNG:      return @"long";
 	case _C_ULNG:     return @"unsigned long";
-//	case _C_LNG_LNG:  return @"long long";
-//	case _C_ULNG_LNG: return @"unsigned long long";
+#ifdef _C_LNG_LNG
+	case _C_LNG_LNG:  return @"long long";
+	case _C_ULNG_LNG: return @"unsigned long long";
+#endif
 	case _C_FLT:      return @"float";
 	case _C_DBL:      return @"double";
 	case _C_VOID:     return @"void";
