@@ -3,14 +3,14 @@
 
    Copyright (C) 2000-2002,2003,2004,2005 Free Software Foundation, Inc.
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: June 2000
 
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 22805 $
-   $Date: 2006-04-24 08:38:15 +0200 (Mon, 24 Apr 2006) $
+   $Revision: 24297 $
+   $Date: 2006-12-30 18:41:02 +0100 (Sam, 30 Dez 2006) $
 
    <abstract></abstract>
 
@@ -36,7 +36,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOGenericRecord.m 22805 2006-04-24 06:38:15Z ayers $")
+RCS_ID("$Id: EOGenericRecord.m 24297 2006-12-30 17:41:02Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSArray.h>
@@ -160,7 +160,7 @@ static NSRecursiveLock *allGenericRecordsLock = nil;
 
 - (id) initWithEditingContext: (EOEditingContext *)context
              classDescription: (EOClassDescription *)classDesc
-                     globalID: (EOGlobalID *)globalID;
+                     globalID: (EOGlobalID *)globalID
 {
   if ((self = [self init]))
     {
