@@ -6,8 +6,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: September 2000
 
-   $Revision: 21645 $
-   $Date: 2005-08-17 10:07:57 +0200 (Mit, 17 Aug 2005) $
+   $Revision: 24297 $
+   $Date: 2006-12-30 18:41:02 +0100 (Sam, 30 Dez 2006) $
 
    <abstract>
    EOKeyValueArchiver object is used to archive a tree of objects into a 
@@ -60,7 +60,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOKeyValueArchiver.m 21645 2005-08-17 08:07:57Z ayers $")
+RCS_ID("$Id: EOKeyValueArchiver.m 24297 2006-12-30 17:41:02Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSString.h>
@@ -621,7 +621,7 @@ NO if no object is found **/
 
 /** Returns unarchived object for the reference archived as 'key'. 
 The receiver gets the object for reference by calling 
-its delegate method -archiver:objectForReference: **/
+its delegate method -unarchiver:objectForReference: **/
 - (id) decodeObjectReferenceForKey: (NSString*)key
 {
   id objectReference = nil;
@@ -838,11 +838,12 @@ class instances should implements -initWithKeyValueUnarchiver: **/
 
 @implementation NSObject (EOKeyValueUnarchiverDelegation)
 
-/** Returns an object for archived 'reference'.
-Should be overriden by EOKeyValueUnarchiver's delegates 
-**/
+/** 
+ * Returns an object for archived 'reference'.
+ * Implemented by EOKeyValueUnarchiver's delegate.
+ */
 - (id)unarchiver: (EOKeyValueUnarchiver*)archiver 
-objectForReference: (id)reference
+objectForReference: (id)keyPath
 {
   [self subclassResponsibility:_cmd];
   return nil;
@@ -856,11 +857,13 @@ objectForReference: (id)reference
 - (void)finishInitializationWithKeyValueUnarchiver: (EOKeyValueUnarchiver *)unarchiver
 {
   //Does nothing ?
+  return;
 }
 
-- (void)awakeFromKeyValueUnarchiver: (EOKeyValueUnarchiver *)unarchiver;
+- (void)awakeFromKeyValueUnarchiver: (EOKeyValueUnarchiver *)unarchiver
 {
   //Does nothing ?
+  return;
 }
 
 @end 
