@@ -6,13 +6,13 @@
    Author: Mircea Oancea <mircea@jupiter.elcom.pub.ro>
    Date: November 1996
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
    Author: Manuel Guesdon <mguesdon@oxymium.net>
    Date: January 2002
 
-   Author: David Ayers <d.ayers@inode.at>
+   Author: David Ayers <ayers@fsfe.org>
    Date: February 2003
 
 
@@ -40,7 +40,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOKeyValueCoding.m 22805 2006-04-24 06:38:15Z ayers $")
+RCS_ID("$Id: EOKeyValueCoding.m 24314 2007-01-04 22:51:31Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSObject.h>
@@ -254,7 +254,7 @@ initialize(void)
  * returned by invoking [NSObject-valueForKey:]
  * for each item in the receiver, substituting EONull for nil.
  * Keys formated like "@function.someKey" are resolved by invoking
- * [NSArray-computeFuncionWithKey:] "someKey" on the receiver.
+ * <code>NSArray compute<em>Function</em>WithKey:</code> "someKey" on the receiver.
  * If the key is omitted, the function will be called with nil.
  * The following functions are supported by default:
  * <list>
@@ -431,7 +431,7 @@ initialize(void)
  * Iterates over the objects of the receiver send each object valueForKey:
  * with the parameter.  The decimalValue of the returned object is accumalted
  * and then divided by number of objects contained by the receiver as returned
- * by [NSArray-coung].  An empty array returns NSDecimalNumber 0.
+ * by <code>NSArray count</code>.  An empty array returns NSDecimalNumber 0.
  */
 - (id)computeAvgForKey: (NSString *)key
 {
@@ -458,7 +458,11 @@ initialize(void)
           right = [[GDL2_ObjectAtIndexWithImp(self,oaiIMP,i) valueForKey: key] decimalValue];
           NSDecimalAdd(&result, &left, &right, mode);
         }
-    };
+    }
+  else
+    {
+      return [NSDecimalNumber zero];
+    }
 
   left  = result;
   NSDecimalFromComponents(&right, (unsigned long long) count, 0, NO);
