@@ -6,11 +6,11 @@
    Author: Mircea Oancea <mircea@jupiter.elcom.pub.ro>
    Date: November 1996
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
-   $Revision: 21645 $
-   $Date: 2005-08-17 10:07:57 +0200 (Mit, 17 Aug 2005) $
+   $Revision: 23510 $
+   $Date: 2006-09-14 18:06:21 +0200 (Don, 14 Sep 2006) $
 
    <abstract></abstract>
 
@@ -36,7 +36,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOKeyValueCodingBase.m 21645 2005-08-17 08:07:57Z ayers $")
+RCS_ID("$Id: EOKeyValueCodingBase.m 23510 2006-09-14 16:06:21Z ayers $")
 
 #import <Foundation/NSObject.h>
 #import <Foundation/NSArray.h>
