@@ -6,8 +6,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 23472 $
-   $Date: 2006-09-12 21:36:24 +0200 (Die, 12 Sep 2006) $
+   $Revision: 24307 $
+   $Date: 2007-01-03 06:43:12 +0100 (Mit, 03 Jän 2007) $
 
    <abstract></abstract>
 
@@ -33,7 +33,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOMutableKnownKeyDictionary.m 23472 2006-09-12 19:36:24Z ayers $")
+RCS_ID("$Id: EOMutableKnownKeyDictionary.m 24307 2007-01-03 05:43:12Z ratmice $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSArray.h>
@@ -172,21 +172,6 @@ RCS_ID("$Id: EOMutableKnownKeyDictionary.m 23472 2006-09-12 19:36:24Z ayers $")
   //EOFLogC("GSWElementIDString end of dealloc");
 }
 
-- (void)gcDecrementRefCountOfContainedObjects
-{
-//    [X gcDecrementRefCount];
-}
-
-- (BOOL)gcIncrementRefCountOfContainedObjects
-{
-  if (![super gcIncrementRefCountOfContainedObjects])
-    return NO;
-  
-  //[XX gcIncrementRefCount];
-  //[XX gcIncrementRefCountOfContainedObjects];
-  return YES;
-}
-
 - (NSString*)description
 {
   NSString *dscr;
