@@ -1,7 +1,7 @@
 /* -*-objc-*-
    EONSAddOns.h
 
-   Copyright (C) 2000 Free Software Foundation, Inc.
+   Copyright (C) 2000-2002,2003,2004,2005 Free Software Foundation, Inc.
 
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
@@ -21,7 +21,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __EONSAddOns_h__
@@ -46,9 +46,17 @@
     : ( TYPE *)GSAutoreleasedBuffer((ID##_size) * sizeof( TYPE )); \
   TYPE *ID = ID##_base;
 
+
 GDL2CONTROL_EXPORT BOOL
 GSUseStrictWO451Compatibility(NSString *key);
 
+GDL2CONTROL_EXPORT void
+GDL2_ActivateCategory(const char *className, SEL sel, BOOL isInstance);
+
+GDL2CONTROL_EXPORT void
+GDL2_ActivateAllGDL2Categories(void);
+
+
 @interface NSObject (NSObjectPerformingSelector)
 - (NSArray *)resultsOfPerformingSelector: (SEL)sel
                    withEachObjectInArray: (NSArray *)array;
@@ -94,6 +102,10 @@ GSUseStrictWO451Compatibility(NSString *key);
 - (int)parsedFirstVersionSubstring;
 @end
 
+@interface NSString (Extensions)
+- (NSString *)initialCapitalizedString;
+@end
+
 //Ayers: Review
 /* Do not rely on these.  */
 @interface NSString (StringToNumber)
