@@ -1,12 +1,12 @@
 /** 
    EOObjectStoreCoordinator.m <title>EOObjectStoreCoordinator</title>
 
-   Copyright (C) 2000-2002 Free Software Foundation, Inc.
+   Copyright (C) 2000-2002,2003,2004,2005 Free Software Foundation, Inc.
 
    Date: June 2000
 
-   $Revision: 1.11 $
-   $Date: 2004/03/19 16:41:20 $
+   $Revision: 21645 $
+   $Date: 2005-08-17 10:07:57 +0200 (Mit, 17 Aug 2005) $
 
    <abstract></abstract>
 
@@ -26,13 +26,13 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
    </license>
 **/
 
 #include "config.h"
 
-RCS_ID("$Id: EOObjectStoreCoordinator.m,v 1.11 2004/03/19 16:41:20 ayers Exp $")
+RCS_ID("$Id: EOObjectStoreCoordinator.m 21645 2005-08-17 08:07:57Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSString.h>
@@ -151,16 +151,19 @@ NSString *EOCooperatingObjectStoreNeeded = @"EOCooperatingObjectStoreNeeded";
 }
 
 - (void) requestStoreForGlobalID: (EOGlobalID *)globalID
-              fetchSpecification: (id)param1
+              fetchSpecification: (EOFetchSpecification *)fetchSpec
                           object: (id)object
 {
-  //TODO if object!=nil or fetchsec !=nil
+  NSMutableDictionary *dict = [NSMutableDictionary dictionary];
+
+  if (globalID)  [dict setObject: globalID forKey: @"globalID"];
+  if (fetchSpec) [dict setObject: fetchSpec forKey: @"fetchSpecification"];
+  if (object)    [dict setObject: object forKey: @"object"];
+
   [[NSNotificationCenter defaultCenter]
     postNotificationName: EOCooperatingObjectStoreNeeded
     object: self
-    userInfo: [NSDictionary dictionaryWithObject: globalID
-			    forKey: @"globalID"]];
-
+    userInfo: dict];
 }
 
 - (EOCooperatingObjectStore*)objectStoreForGlobalID: (EOGlobalID *)globalID
@@ -457,21 +460,37 @@ NSString *EOCooperatingObjectStoreNeeded = @"EOCooperatingObjectStoreNeeded";
                       editingContext: context];
 }
 
+/*
+ * If there is only one store that we are coordinating then all our
+ * objects were also invalidated.
+ */
 - (void) _invalidatedAllObjectsInSubStore: (NSNotification*)notification
 {
-  [self notImplemented: _cmd]; //TODO
+  if ([_stores count] == 1)
+    {
+      NSAssert2([_stores containsObject: [notification object]],
+		@"recived notification %@ for foreign store %@",
+		notification, _stores);
+      [[NSNotificationCenter defaultCenter]
+        postNotificationName: EOInvalidatedAllObjectsInStoreNotification
+        object: self
+        userInfo: nil];
+    }
 }
 
+/*
+ * Let the EOEditingContexts know that some objects changed.
+ */
 - (void) _objectsChangedInSubStore: (NSNotification*)notification
 {
-  EOFLOGObjectFnStart(); //TODO
+  EOFLOGObjectFnStart();
 
   if ([notification object] != self)
     {
       [[NSNotificationCenter defaultCenter]
         postNotificationName: EOObjectsChangedInStoreNotification
         object: self
-        userInfo: [notification userInfo]]; //call _objectsChangedInStore: # EditingContext
+        userInfo: [notification userInfo]];
     }
 
   EOFLOGObjectFnStop();
@@ -494,48 +513,61 @@ NSString *EOCooperatingObjectStoreNeeded = @"EOCooperatingObjectStoreNeeded";
 
 - (void)invalidateObjectsWithGlobalIDs: (NSArray *)globalIDs
 {
-  NSMutableArray *buf;
-  NSMutableArray *gids, *gidsToRemove;
-  NSEnumerator *gidEnum;
+  NSMapTable *gidsByStore;
+  NSMapEnumerator gbsEnum;
   EOCooperatingObjectStore *store;
   EOGlobalID *gid;
+  NSMutableArray *array;
+  unsigned i,n;
 
   EOFLOGObjectFnStart();
 
-  buf  = [NSMutableArray arrayWithArray: globalIDs];
-  gids = [NSMutableArray arrayWithCapacity: [globalIDs count]];
-  gidsToRemove = [NSMutableArray arrayWithCapacity: 16];
+  gidsByStore = NSCreateMapTable(NSNonOwnedPointerMapKeyCallBacks,
+				 NSNonOwnedPointerMapValueCallBacks,
+				 8);
 
-  while (YES)
+  for (i=0, n=[globalIDs count]; i<n; i++)
     {
-      if (![buf count])
-	break;
+      gid = [globalIDs objectAtIndex: i];
+      store = [self objectStoreForGlobalID: gid];
 
-      store = nil;
+      NSAssert1(store,@"No store found for gid:%@", gid);
 
-      gidEnum = [buf objectEnumerator];
-      while ((gid = [gidEnum nextObject]))
+      array = NSMapGet(gidsByStore, store);
+      if (array == nil)
 	{
-	  if (store == nil)
-	    {
-	      if ((store = [self objectStoreForGlobalID: gid]) == nil)
-		[buf addObject: gid];
-	    }
-	  else if ([store ownsGlobalID: gid] == YES)
-	    [gids addObject: gid];
+	  array = [NSMutableArray array];
+	  NSMapInsertKnownAbsent(gidsByStore, store, array);
 	}
-
-      [store invalidateObjectsWithGlobalIDs: gids];
-
-      [buf  removeObjectsInArray: gids];
-      [buf  removeObjectsInArray: gidsToRemove];
-      [gids removeAllObjects];
-      [gidsToRemove removeAllObjects];
+      [array addObject: gid];
     }
 
+  gbsEnum = NSEnumerateMapTable(gidsByStore);
+  while (NSNextMapEnumeratorPair(&gbsEnum, (void**)&store, (void**)&array))
+    {
+      [store invalidateObjectsWithGlobalIDs: array];
+    }
+
+  NSEndMapTableEnumeration(&gbsEnum);
+  NSFreeMapTable(gidsByStore);
+
   EOFLOGObjectFnStop();
 }
 
+- (void)lockObjectWithGlobalID: (EOGlobalID *)gid
+                editingContext: (EOEditingContext *)context
+{
+  EOObjectStore *store = [self objectStoreForGlobalID: gid];
+  [store lockObjectWithGlobalID: gid editingContext: context];
+}
+
+- (BOOL)isObjectLockedWithGlobalID: (EOGlobalID *)gid
+		    editingContext: (EOEditingContext *)context
+{
+  EOObjectStore *store = [self objectStoreForGlobalID: gid];
+  return [store isObjectLockedWithGlobalID: gid editingContext: context];
+}
+
 @end
 
 
