@@ -3,12 +3,12 @@
 
    Copyright (C) 2000,2002,2003,2004,2005 Free Software Foundation, Inc.
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
-   Author: David Ayers <d.ayers@inode.at>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
+   Author: David Ayers <ayers@fsfe.org>
    Date: June 2000
 
-   $Revision: 23490 $
-   $Date: 2006-09-13 22:44:53 +0200 (Mit, 13 Sep 2006) $
+   $Revision: 24297 $
+   $Date: 2006-12-30 18:41:02 +0100 (Sam, 30 Dez 2006) $
 
    <abstract></abstract>
 
@@ -34,7 +34,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOObserver.m 23490 2006-09-13 20:44:53Z ratmice $")
+RCS_ID("$Id: EOObserver.m 24297 2006-12-30 17:41:02Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSMapTable.h>
@@ -64,7 +64,7 @@ RCS_ID("$Id: EOObserver.m 23490 2006-09-13 20:44:53Z ratmice $")
  * all mutating accessor methods before the state of the receiver changes.
  * This method invokes [EOObserverCenter+notifyObserversObjectWillChange:]
  * with the receiver.  It is responsible for invoking 
- * [EOObserving-objectWillChange:] for all corresponding observers.
+ * [(EOObserving)-objectWillChange:] for all corresponding observers.
  */
 - (void)willChange
 {
@@ -80,14 +80,14 @@ RCS_ID("$Id: EOObserver.m 23490 2006-09-13 20:44:53Z ratmice $")
 
 /**
  * <p>This is the central coordinating class of the change tracking system
- * of EOControl.  It manages the observers [EOObserving] and the objects
+ * of EOControl.  It manages the observers [(EOObserving)] and the objects
  * to be observed.  No instances of this class should be needed or created.
  * All methods for coordinating the tracking mechanism are class methods.</p>
- * <p>Observers must implement the [EObserving] protocol, in particular
- * [EOObserving-objectWillChange:] while the observed objects must invoke
+ * <p>Observers must implement the [(EOObserving)] protocol, in particular
+ * [(EOObserving)-objectWillChange:] while the observed objects must invoke
  * [NSObject-willChange].  Invoke [+addObserver:forObject:] to register an
  * observer for a particular object.  That will setup for 
- * [EOObserving-objectWillChange:] to be invoked on the observer each time
+ * [(EOObserving)-objectWillChange:] to be invoked on the observer each time
  * [NSObject-willChange] gets called.  To remove an observer invoke 
  * [+removeObserver:forObject:].  For observers who wish to be notified for
  * every change the methods [+addOmniscientObserver:] and 
@@ -97,7 +97,7 @@ RCS_ID("$Id: EOObserver.m 23490 2006-09-13 20:44:53Z ratmice $")
 @implementation EOObserverCenter
 
 static NSMapTable *observersMap = NULL;
-static GDL2NonRetainingMutableArray *omniscientObservers = NULL;
+static NSHashTable *omniscientHash = NULL;
 static unsigned int notificationSuppressCount=0;
 static id lastObject;
 
@@ -107,44 +107,53 @@ static id lastObject;
   observersMap = NSCreateMapTable(NSNonOwnedPointerMapKeyCallBacks,
 				  NSNonOwnedPointerMapValueCallBacks,
 				  32);
-  omniscientObservers = [[GDL2NonRetainingMutableArray alloc] initWithCapacity:32];
+  omniscientHash = NSCreateHashTable(NSNonOwnedPointerHashCallBacks, 0);
   lastObject = nil;
 
   notificationSuppressCount = 0;
 }
 
 /**
- * Adds the observer to be notified with a [EOObserving-objectWillChange:] 
+ * <p>
+ * Adds the observer to be notified with a [(EOObserving)-objectWillChange:] 
  * on the first of consecutive [NSObject-willChange] methods invoked on
- * the object.  This does not retain the object.  It is the observers
- * responsibility to unregister the object with [-removeObserver:forObject:]
+ * the object.
+ * </p>
+ * <p>
+ * This does not retain the object.  It is the observers
+ * responsibility to unregister the object with [+removeObserver:forObject:]
  * before the object ceases to exist.
  * The observer is also not retained.  It is the observers responsibility
  * to unregister before it ceases to exist.
+ * </p>
+ * <p>
+ * Both observer and object equality are considered equal through pointer
+ * equality, so an observer observing multiple objects considered
+ * <code>isEqual:</code>
+ * will recieve multiple observer notifications,
+ * objects considered <code>isEqual:</code> may contain different sets of
+ * observers, and an object can have multiple observers considered 
+ * <code>isEqual:</code>.
+ * </p>
  */
 + (void)addObserver: (id <EOObserving>)observer forObject: (id)object
 {
-  GDL2NonRetainingMutableArray *observersArray;
+  NSHashTable *observersHash;
 
-  observersArray = NSMapGet(observersMap, object);
+  if (observer == nil || object == nil)
+    return;
+  
+  observersHash = NSMapGet(observersMap, object);
 
-  if (observersArray == nil)
+  if (observersHash == NULL)
     {
-      observersArray = [[GDL2NonRetainingMutableArray alloc] initWithCapacity:16];
-      [observersArray addObject: observer];
-
-      /* The object is not retained.  It is the responsibility
-	 of the observer to remove the object before it ceases
-	 to exist.  */ 
-      NSMapInsert(observersMap, object, observersArray);
+      observersHash = NSCreateHashTable(NSNonOwnedPointerHashCallBacks, 0);
+      NSMapInsert(observersMap, object, observersHash);
+      NSHashInsert(observersHash, observer);
     }
   else
     {
-      if (![observersArray containsObject:observer])
-	[observersArray addObject:observer];
-      else
-	NSDebugMLog(@"Observer: %@ for object: %@(%p) added multiple times.",
-		    observer, NSStringFromClass(GSObjCClass(object)), object);
+      NSHashInsertIfAbsent(observersHash, observer);
     }
 }
 
@@ -154,20 +163,21 @@ static id lastObject;
  */
 + (void)removeObserver: (id <EOObserving>)observer forObject: (id)object
 {
-  GDL2NonRetainingMutableArray *observersArray;
+  NSHashTable *observersHash;
 
-  observersArray = NSMapGet(observersMap, object);
+  if (observer == nil || object == nil)
+    return;
 
-  if (observersArray)
+  observersHash = NSMapGet(observersMap, object);
+
+  if (observersHash)
     {
-      [observersArray removeObject: observer];
-      
-      if (![observersArray count])
+      NSHashRemove(observersHash, observer);
+
+      if (NSCountHashTable(observersHash) == 0)
         {
+	  NSFreeHashTable(observersHash);
           NSMapRemove(observersMap, object);
-	  /* The object is not released.  It is the responsibility
-	     of the observer to remove the object before it ceases 
-	     to exist.  */ 
         }
     }
 }
@@ -179,7 +189,7 @@ static id lastObject;
 
 /**
  * This method is invoked from [NSObject-willChange] to dispatch
- * [EOObserving-objectWillChange:] to all observers registered
+ * [(EOObserving)-objectWillChange:] to all observers registered
  * to observe object.  This method records the last object it was
  * invoked with so that subsequent invocations with the same object
  * get ignored.  Invoke this method with nil as the object to insure
@@ -202,30 +212,45 @@ static id lastObject;
 
       if (object == nil)
 	{
-	  lastObject = nil;
-          [omniscientObservers makeObjectsPerform:objectWillChangeSel
-                                       withObject:nil];
+	  NSHashEnumerator omniscEnum = NSEnumerateHashTable(omniscientHash);
+	  id obj;
 
+	  lastObject = nil;
+	  while ((obj = (id)NSNextHashEnumeratorItem(&omniscEnum)))
+	    {
+	      [obj performSelector:objectWillChangeSel withObject:object];
+	    }
 	}
       else if (lastObject != object)
 	{
-	  GDL2NonRetainingMutableArray *observersArray;
-	  int c;
+	  NSHashTable *observersHash;
+	  NSHashEnumerator observersEnum;
+	  id obj;
 
 	  lastObject = object;
 
-	  observersArray = NSMapGet(observersMap, object);
-	  c = [observersArray count];
-          EOFLOGObjectLevelArgs(@"EOObserver", @"observersArray count=%d",
-			      	c);
-	      
-	  [observersArray makeObjectsPerform:objectWillChangeSel
-		  		  withObject:object];
-	  c = [omniscientObservers count];
+	  observersHash = NSMapGet(observersMap, object);
+
+	  if (observersHash)
+	    {
+	      observersEnum = NSEnumerateHashTable(observersHash);
+              EOFLOGObjectLevelArgs(@"EOObserver", @"observersArray count=%d",
+			      	NSCountHashTable(observersHash));
+	     
+	      while ((obj = (id)NSNextHashEnumeratorItem(&observersEnum)))
+	        {
+	          [obj performSelector:objectWillChangeSel withObject:object];
+	        }
+	    }
+	  
           EOFLOGObjectLevelArgs(@"EOObserver", @"omniscientObservers count=%d",
-				c);
-	  [omniscientObservers makeObjectsPerform:objectWillChangeSel
-		  		       withObject:object];
+				NSCountHashTable(omniscientHash));
+
+	  observersEnum = NSEnumerateHashTable(omniscientHash);
+	  while ((obj = (id)NSNextHashEnumeratorItem(&observersEnum)))
+	    {
+	      [obj performSelector:objectWillChangeSel withObject:object];
+	    }
 	}
     }
 
@@ -243,9 +268,17 @@ static id lastObject;
  */
 + (NSArray *)observersForObject: (id)object
 {
-  GDL2NonRetainingMutableArray *observersArray;
-  observersArray = NSMapGet(observersMap, object);
-  return [NSArray arrayWithArray:observersArray];
+  if (object)
+    {
+      NSHashTable *observersHash = NSMapGet(observersMap, object);
+
+      if (observersHash)
+        {
+          return NSAllHashTableObjects(observersHash);
+	}
+    }
+  
+  return nil;
 }
 
 /**
@@ -254,18 +287,23 @@ static id lastObject;
  */
 + (id)observerForObject: (id)object ofClass: (Class)targetClass
 {
-  GDL2NonRetainingMutableArray *observersArray;
-  unsigned i, count;
+  NSHashTable *observersHash;
 
-  observersArray = NSMapGet(observersMap, object);
-
-  count = [observersArray count];
-  for (i = 0; i < count; i++)
+  if (object == nil)
+    return nil;
+    
+  observersHash = NSMapGet(observersMap, object);
+  if (observersHash)
     {
-      id observer = [observersArray objectAtIndex:i];
-
-      if ([observer isKindOfClass: targetClass])
-        return observer;
+      NSHashEnumerator observersEnum;
+      observersEnum = NSEnumerateHashTable(observersHash);
+      id observer;
+      
+      while ((observer = (id)NSNextHashEnumeratorItem(&observersEnum)))
+        {
+          if ([observer isKindOfClass: targetClass])
+            return observer;
+        }
     }
 
   return nil;
@@ -274,7 +312,7 @@ static id lastObject;
 /**
  * Increases the notification suppression count.  When the count is 
  * non zero [+notifyObserversObjectWillChange:] invocations do nothing.  
- * Call [+enableObserverNotificaion] a matching amount of times
+ * Call [+enableObserverNotification] a matching amount of times
  * to enable the dispatch of those notifications again.
  */
 + (void)suppressObserverNotification
@@ -286,9 +324,9 @@ static id lastObject;
  * Decreases the notification suppression count.  This should be called
  * to pair up [+suppressObserverNotification] invocations.  When they
  * all have been paired up [+notifyObserversObjectWillChange:] will
- * continue to dispatch [EOObserving-objectWillChange:] methods again.
- * If this is invoked when the [+observerNotificationCount] is 0, this
- * method raises an NSInternalInconsistencyException.
+ * continue to dispatch [(EOObserving)-objectWillChange:] methods again.
+ * If this is invoked when the [+observerNotificationSuppressCount] is 0,
+ * this method raises an NSInternalInconsistencyException.
  */
 + (void)enableObserverNotification
 {
@@ -313,12 +351,12 @@ static id lastObject;
 
 /**
  * Adds observer as an omniscient observer to receive 
- * [EOObserving-objectWillChange:] for all objects and nil.
+ * [(EOObserving)-objectWillChange:] for all objects and nil.
  */
 + (void)addOmniscientObserver: (id <EOObserving>)observer
 {
-  if (![omniscientObservers containsObject:observer])
-    [omniscientObservers addObject: observer];
+  if (observer)
+    NSHashInsertIfAbsent(omniscientHash, observer);
 }
 
 /**
@@ -326,7 +364,8 @@ static id lastObject;
  */
 + (void)removeOmniscientObserver: (id <EOObserving>)observer
 {
-  [omniscientObservers removeObject: observer];
+  if (observer)
+    NSHashRemove(omniscientHash, observer);
 }
 
 @end
@@ -335,7 +374,7 @@ static id lastObject;
 @implementation EODelayedObserver
 
 /**
- * EOObserving implementation which enqueues the receiver in the
+ * [(EOObserving)] implementation which enqueues the receiver in the
  * queue returned by observerQueue.
  */
 - (void)objectWillChange: (id)subject
@@ -364,13 +403,14 @@ static id lastObject;
 }
 
 /**
- * Invoked by [EODelayedObserverQueue-notifyObserverUpToPriority:] or 
+ * Invoked by [EODelayedObserverQueue-notifyObserversUpToPriority:] or 
  * [EODelayedObserverQueue-enqueueObserver:].  Overridden by subclasses
  * to process the delayed change notification.  EODelayesObserver does
  * nothing.
  */
 - (void)subjectChanged
 {
+  return;
 }
 
 /**
@@ -388,14 +428,15 @@ static id lastObject;
 
 /**
  * EODelayedObserverQueue manages the delayed observer notifications
- * for [EODelayedObservers] that register with it.  A delayed observer
+ * for [EODelayedObserver] that register with it.  A delayed observer
  * may only register itself with one queue and a fixed priority.  
  * Upon [-notifyObserversUpToPriority:] all enqueued observers are sent
- * [EODelyedObserver-subjectChanged] according to the EOObserverPriority
+ * [EODelayedObserver-subjectChanged] according to the EOObserverPriority
  * of the observer.  The first time an observer is enqueued with
  * [-enqueueObserver:] (with a priority other than 
  * EOObserverPriorityImmediate) the queue registers itself with the
- * [NSRunLoop-currentRunLoop] with EOFlushDelayedObserverRunLoopOrdering
+ * <code>NSRunLoop currentRunLoop</code> with
+ * EOFlushDelayedObserverRunLoopOrdering
  * to invoke [-notifyObserversUpToPriority:] with EOObserverPrioritySixth.
  * In general this mechanism is used by [EOAssociation] subclasses and
  * in part [EODisplayGroup] or even [EOEditingContext].
@@ -446,11 +487,12 @@ static EODelayedObserverQueue *observerQueue;
  * for the current processing.</p>
  * <p>Upon the first invocation within a run loop, this method registers
  * a callback method to have [-notifyObserversUpToPriority:] invoked
- * with EOObserverPrioritySixth with the [NSRunLoop-currentRunLoop] with
+ * with EOObserverPrioritySixth with the
+ * <code>NSRunLoop currentRunLoop </code>with
  * EOFlushDelayedObserverRunLoopOrdering and the receivers run loop modes.</p>
  * <p>The observer is not retained and should be removed from the receiver
- * with [-dequeueObserver:] during the EODelayedObservers [NSObject-dealloc]
- * method.</p>
+ * with [-dequeueObserver:] during the EODelayedObservers
+ * <code>NSObject dealloc</code> method.</p>
  */
 - (void)enqueueObserver: (EODelayedObserver *)observer
 {
@@ -599,7 +641,7 @@ static EODelayedObserverQueue *observerQueue;
 /**
  * Sets the run loop modes the receiver uses when registering
  * for [-notifyObserversUpToPriority:] during [-enqueueObserver:].
- * (see [NSRunLoop]).
+ * (see <code>NSRunLoop</code>).
  */
 - (void)setRunLoopModes: (NSArray *)modes
 {
@@ -609,7 +651,7 @@ static EODelayedObserverQueue *observerQueue;
 /**
  * Returns the run loop modes the receiver uses when registering
  * for [-notifyObserversUpToPriority:] during [-enqueueObserver:].
- * (see [NSRunLoop]).
+ * (see <code>NSRunLoop</code>).
  */
 - (NSArray *)runLoopModes
 {
