@@ -5,8 +5,8 @@
 
    Date: Jan 2005
 
-   $Revision: 21651 $
-   $Date: 2005-08-17 20:57:13 +0200 (Mit, 17 Aug 2005) $
+   $Revision: 23874 $
+   $Date: 2006-10-15 14:23:42 +0200 (Son, 15 Okt 2006) $
 
    <abstract></abstract>
 
@@ -32,7 +32,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOPrivate.m 21651 2005-08-17 18:57:13Z ayers $")
+RCS_ID("$Id: EOPrivate.m 23874 2006-10-15 12:23:42Z ratmice $")
 
 #include <Foundation/Foundation.h>
 #define GSI_ARRAY_TYPES GSUNION_OBJ
@@ -588,8 +588,8 @@ static SEL eqSel;
   return GSIArrayItemAtIndex(_contents, 0).obj;
 }
 
-/* not only make it faster but work around buggy implementations in gnustep
- * with an extra release */
+/* not only make it faster but work around for old buggy implementations of
+ * NSArray in gnustep with an extra release */
 - (void) removeObject:(id)anObject
 {
   int index = GSIArrayCount(_contents);
