@@ -3,11 +3,11 @@
 
    Copyright (C) 2000,2002,2003,2004,2005 Free Software Foundation, Inc.
 
-   Author: Mirko Viviani <mirko.viviani@rccr.cremona.it>
+   Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
-   $Revision: 22157 $
-   $Date: 2005-12-05 21:35:08 +0100 (Mon, 05 Dez 2005) $
+   $Revision: 23510 $
+   $Date: 2006-09-14 18:06:21 +0200 (Don, 14 Sep 2006) $
 
    <abstract></abstract>
 
@@ -33,7 +33,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOQualifier.m 22157 2005-12-05 20:35:08Z ayers $")
+RCS_ID("$Id: EOQualifier.m 23510 2006-09-14 16:06:21Z ayers $")
 
 #include <stdio.h>
 #include <string.h>
