@@ -3,7 +3,7 @@
 
    Copyright (C) 2005 Free Software Foundation, Inc.
 
-   Author: David Ayers <d.ayers@inode.at>
+   Author: David Ayers <ayers@fsfe.org>
    Date: November 2005
 
    This file is part of the GNUstep Database Library.
@@ -26,7 +26,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOSharedEditingContext.m 22117 2005-11-28 22:10:05Z ayers $")
+RCS_ID("$Id: EOSharedEditingContext.m 24297 2006-12-30 17:41:02Z ayers $")
 
 #ifndef GNUSTEP
 #include <GNUstepBase/GNUstep.h>
@@ -39,6 +39,7 @@ RCS_ID("$Id: EOSharedEditingContext.m 22117 2005-11-28 22:10:05Z ayers $")
 #include <Foundation/NSNotification.h>
 #include <Foundation/NSSet.h>
 #include <Foundation/NSString.h>
+#include <Foundation/NSUndoManager.h>
 #endif
 
 #include <GNUstepBase/GSLock.h>
@@ -48,7 +49,6 @@ RCS_ID("$Id: EOSharedEditingContext.m 22117 2005-11-28 22:10:05Z ayers $")
 #include "EOFetchSpecification.h"
 #include "EOGlobalID.h"
 #include "EOObjectStoreCoordinator.h"
-#include "EOUndoManager.h"
 
 
 NSString *EODefaultSharedEditingContextWasInitializedNotification
@@ -420,6 +420,7 @@ static EOSharedEditingContext *dfltSharedEditingContext = nil;
  */
 - (void)reset
 {
+  return;
 }
 
 /**
@@ -551,6 +552,7 @@ static EOSharedEditingContext *dfltSharedEditingContext = nil;
  */
 - (void)validateChangesForSave
 {
+  return;
 }
 
 /**
@@ -580,7 +582,7 @@ static EOSharedEditingContext *dfltSharedEditingContext = nil;
  * Raises an NSInternalInconsistencyException
  * since objects in a shared editing context may not be modified.
  */
-- (void)objectWillChange: (id)object;
+- (void)objectWillChange: (id)object
 {
   [NSException raise: NSInternalInconsistencyException
 	       format: @"+[%@ deleteObject:] attempted to delete object in shared editing context", [self class]];
