@@ -6,8 +6,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 21645 $
-   $Date: 2005-08-17 10:07:57 +0200 (Mit, 17 Aug 2005) $
+   $Revision: 24297 $
+   $Date: 2006-12-30 18:41:02 +0100 (Sam, 30 Dez 2006) $
 
    <abstract></abstract>
 
@@ -33,7 +33,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOUndoManager.m 21645 2005-08-17 08:07:57Z ayers $")
+RCS_ID("$Id: EOUndoManager.m 24297 2006-12-30 17:41:02Z ayers $")
 
 #ifndef GNUSTEP
 #include <GNUstepBase/GNUstep.h>
@@ -46,7 +46,7 @@ RCS_ID("$Id: EOUndoManager.m 21645 2005-08-17 08:07:57Z ayers $")
 
 @implementation EOUndoManager
 
-- (void) forgetAllWithTarget: (id)param0
+- (void) forgetAllWithTarget: (id)target
 {
   EOFLOGObjectFnStart();
 
@@ -65,8 +65,8 @@ RCS_ID("$Id: EOUndoManager.m 21645 2005-08-17 08:07:57Z ayers $")
 }
 
 - (void) registerUndoWithTarget: (id)target
-                       selector: (SEL)sel
-                            arg: (id)arg
+                       selector: (SEL)selector
+                            arg: (id)argument
 {
   EOFLOGObjectFnStart();
 
