@@ -3,7 +3,7 @@
   
   Copyright (C) 2005 Free Software Foundation, Inc.
  
-  Author: Matt Rice <ratmice@yahoo.com>
+  Author: Matt Rice <ratmice@gmail.com>
   Date: April 2005
   
   This file is part of the GNUstep Database Library.
@@ -176,7 +176,7 @@ NSString *EOMConsistencyModelObjectKey = @"EOMConsistencyModelObjectKey";
 - (EOAdaptor *)adaptor
 {
   NS_DURING
-    return [EOAdaptor adaptorWithModel:_model];
+    NS_VALUERETURN([EOAdaptor adaptorWithModel:_model], EOAdaptor *);
   NS_HANDLER
     return nil;
   NS_ENDHANDLER
@@ -229,11 +229,12 @@ NSString *EOMConsistencyModelObjectKey = @"EOMConsistencyModelObjectKey";
 
 - (BOOL)saveToPath:(NSString *)path
 {
-  if (![[path pathExtension] isEqual:@"eomodeld"])
+  NSString *ext = [path pathExtension];
+  if (!([ext isEqual:@"eomodeld"] || [ext isEqual:@"eomodel"]))
     path = [path stringByAppendingPathExtension:@"eomodeld"];
   NS_DURING
     [_model writeToFile: path];
-    return YES;
+    NS_VALUERETURN(YES, BOOL);
   NS_HANDLER
        NSRunAlertPanel(@"Error",
 		       @"Save failed: %@",
@@ -336,7 +337,7 @@ NSString *EOMConsistencyModelObjectKey = @"EOMConsistencyModelObjectKey";
      }
    
   [newEntity setName: entityNumber
-	  	      ? [NSString stringWithFormat: @"Entity%i",entityNumber]
+	  	      ? [NSString stringWithFormat: @"Entity%i", entityNumber]
 		      : @"Entity"];
   [newEntity setClassName:@"EOGenericRecord"];
   [_editingContext insertObject:newEntity];
@@ -665,6 +666,14 @@ NSString *EOMConsistencyModelObjectKey = @"EOMConsistencyModelObjectKey";
 
 - (void) windowWillClose:(NSNotification *)notif
 {
+  if ([_editors containsObject:[EOMApp currentEditor]])
+    {
+      // Clear inspected object.
+      [[EOMApp currentEditor] setSelectionPath:[NSArray array]];
+      // No longer current editor
+      [EOMApp setCurrentEditor:nil];
+    }
+  
   [EOMApp removeDocument:self];  
 }
 
