@@ -1,3 +1,27 @@
+/**
+    ConnectInspector.m
+
+    Author: Matt Rice <ratmice@gmail.com>
+    Date: 2005, 2006
+
+    This file is part of GDL2Palette.
+
+    <license>
+    GDL2Palette is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    GDL2Palette is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with GDL2Palette; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    </license>
+**/
 #include "ConnectionInspector.h"
 #include "Foundation+Categories.h"
 
@@ -32,21 +56,11 @@
 - (NSArray *) _associationClassesUsableWithObject:(id)anObject;
 @end
 
-/* TODO get notifications for IB{Will,Did}RemoveConnectorNotification
- * and remove the object from the _objectToAssociation map table if
- * there are no more connectors for it */
-static NSMapTable *_objectToAssociation;
 @interface NSApplication(missingStuff)
 - (GormClassManager *)classManager;
 @end
 
 @implementation GDL2ConnectionInspector
-+ (void) initialize
-{
-  _objectToAssociation = NSCreateMapTableWithZone(NSObjectMapKeyCallBacks,
-	 					  NSObjectMapValueCallBacks,
-		  	   			  0, [self zone]); 
-}
 
 - (NSButton *)okButton
 {
@@ -164,6 +178,7 @@ static NSMapTable *_objectToAssociation;
   if (repObj == nil)
     {
       /* gorm specific... but couldn't find a public standard api replacement */
+      /* see bug #17822 */
       _keys = RETAIN([[NSApp classManager] allOutletsForObject:object]);
       _signatures = nil;
     }
@@ -210,6 +225,23 @@ static NSMapTable *_objectToAssociation;
   return AUTORELEASE(ret);
 }
 
+- (NSArray *) _localKeysFromDisplayGroup:(EODisplayGroup *)dg
+{
+  NSMutableArray *ret = [[NSMutableArray alloc] init];
+  NSArray *local = [dg localKeys];
+  int i,c;
+  
+  for (i = 0, c = [local count]; i < c; i++)
+    {
+      id obj = [local objectAtIndex:i];
+      id key = [KeyWrapper wrapperWithKey:obj type:LocalType];
+
+      [ret addObject:key];
+    }
+
+  return AUTORELEASE(ret);
+}
+
 /* for normal outlets/actions */
 - (NSArray *) _keysFromArray:(NSArray *)arr
 {
@@ -234,6 +266,7 @@ static NSMapTable *_objectToAssociation;
 	  id cd = [ds classDescriptionForObjects];
 	  [_values addObjectsFromArray:[self _keysFromClassDescription:cd]];
         }
+      [_values addObjectsFromArray:[self _localKeysFromDisplayGroup:dest]];
     }
 }
 
@@ -395,10 +428,23 @@ static NSMapTable *_objectToAssociation;
 
 	  if (!found)
 	    {
-	      ASSIGN(_association,NSMapGet(_objectToAssociation, object));
+	      NSArray *aConns = [[(id<IB>)NSApp activeDocument] connectorsForSource:object ofClass:[EOAspectConnector class]];
+	      Class assocClass = [[popUp selectedItem] representedObject];
+	      
+	      _association = nil;
+
+	      for (i = 0; i < c; i++)
+	        {
+		  EOAspectConnector *aConn = [aConns objectAtIndex:i];
+		  EOAssociation *assoc = [aConn association];
+		  if ([[assoc class] isEqual: assocClass])
+		    {
+		      ASSIGN(_association, assoc);
+		    }
+	        }
+
 	      if (!_association)
 	        {
-  		  Class assocClass = [[popUp selectedItem] representedObject];
 		  _association = [[assocClass alloc] initWithObject:object];
 	          /* this shouldn't happen until ok:. */
 		}
@@ -438,9 +484,12 @@ static NSMapTable *_objectToAssociation;
               for (i = 1; i < column; i++)
                 {
                   int aRow = [sender selectedRowInColumn:i];
-                  val = [vals objectAtIndex:aRow];
 
-                  if ([val keyType] != AttributeType)
+                  val = [vals objectAtIndex:aRow];
+		  type = [val keyType]; 
+		  
+                  if (type == ToManyRelationshipType
+		      || type == ToOneRelationshipType)
                     {
                       classDesc =
                       [classDesc classDescriptionForDestinationKey:[val key]];
@@ -458,7 +507,8 @@ static NSMapTable *_objectToAssociation;
                         case 'M': wantsTypes |= ToManyRelationshipType; break;
                       }
                   }
-		[okButton setEnabled:(wantsTypes & type)];
+		[okButton setEnabled:(wantsTypes & type)
+				     || (type == LocalType)];
 	    }
 	}
     }
@@ -682,11 +732,13 @@ willDisplayCell:(id)cell atRow:(int)row column:(int)column
 			case 'M': wantsTypes |= ToManyRelationshipType; break;
 		      }
 		  }
-		[cell setLeaf: (type == AttributeType)];
+		[cell setLeaf: (type == AttributeType
+			        || type == LocalType)];
 		// TODO relationships should be NO...
 	        [cell setStringValue: [val key]];
 		[cell setEnabled:(wantsTypes & type)
-				 || (wantsTypes & AttributeType)];
+				 || (wantsTypes & AttributeType)
+				 || (type == LocalType)];
             }
       }
   else if (sender == connectionsBrowser)
@@ -746,7 +798,6 @@ willDisplayCell:(id)cell atRow:(int)row column:(int)column
      else if ([_currentConnector isKindOfClass:[EOAspectConnector class]])
        {
 	 [_connectors addObject:_currentConnector];
-	 NSMapInsert(_objectToAssociation, object, _association);
      	 [[(id<IB>)NSApp activeDocument]
 	  		attachObject:_association toParent:object];
        }
