@@ -1,18 +1,18 @@
 /**
     KeyWrapper.m
 
-    Author: Matt Rice <ratmice@yahoo.com>
+    Author: Matt Rice <ratmice@gmail.com>
     Date: Mar 2006
 
     This file is part of GDL2Palette.
 
     <license>
-    DBModeler is free software; you can redistribute it and/or modify
+    GDL2Palette is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
-    DBModeler is distributed in the hope that it will be useful,
+    GDL2Palette is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
@@ -30,7 +30,9 @@ typedef enum KeyType
   AttributeType		 	= 1,
   ToOneRelationshipType		= 2,
   ToManyRelationshipType 	= 4,
-  OtherType			= 8
+  OtherType			= 8,
+  LocalType			= 16,
+  QueryType			= 32
 }KeyType;
 
 @interface KeyWrapper: NSObject
