@@ -6,8 +6,8 @@
    Author: Stephane Corthesy <stephane@sente.ch>
    Date: February 2003
 
-   $Revision: 21645 $
-   $Date: 2005-08-17 10:07:57 +0200 (Mit, 17 Aug 2005) $
+   $Revision: 23547 $
+   $Date: 2006-09-17 17:41:22 +0200 (Son, 17 Sep 2006) $
 
    <abstract></abstract>
 
@@ -33,7 +33,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: eoutil.m 21645 2005-08-17 08:07:57Z ayers $")
+RCS_ID("$Id: eoutil.m 23547 2006-09-17 15:41:22Z ratmice $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSArray.h>
@@ -138,15 +138,15 @@ usage(BOOL fullUsage)
       "\tset to connectionDictionary.\n"
       "\n"
       "\t   model -- must be the name of an eomodel or eomodeld file\n"
-      "\t   adaptorName -- Postgres95, FlatFile, etc.\n"
+      "\t   adaptorName -- PostgreSQL, FlatFile, etc.\n"
       "\t   connectionDictionary -- string in property list format representing a\n"
       "\t                           dictionary, specifying the database name for the\n"
       "\t                           data source (required) and username and password (if\n"
       "\t                           required by that data source).\n"
       "\t   outFileName -- the name of a directory to write the converted model\n"
       "\n"
-      "\tExample: eoutil convert Movies.eomodeld Postgres95 '{ databaseName = test; hostName = localhost; userName = postgres; password = postgres; }' M.eomodeld\n"
-      "\t         Converts types in Movies.eomodeld file to Postgres95 types and writes\n"
+      "\tExample: eoutil convert Movies.eomodeld PostgreSQL '{ databaseName = test; hostName = localhost; userName = postgres; password = postgres; }' M.eomodeld\n"
+      "\t         Converts types in Movies.eomodeld file to PostgreSQL types and writes\n"
       "\t         the converted model to ./M.eomodel\n"
       "\n"
       "  eoutil connect (<model> | (<adaptorName> <connectionDictionary>))\n"
@@ -156,14 +156,14 @@ usage(BOOL fullUsage)
       "\tprimarily useful for scripts.\n"
       "\n"
       "\t   model -- must be the name of an eomodel or eomodeld file\n"
-      "\t   adaptorName -- Postgres95, FlatFile, etc.\n"
+      "\t   adaptorName -- PostgreSQL, FlatFile, etc.\n"
       "\t   connectionDictionary -- string in property list format representing a\n"
       "\t                           dictionary, specifying the database name for the\n"
       "\t                           data source (required) and username and password (if\n"
       "\t                           required by that data source).\n"
       "\n"
-      "\tExample: eoutil connect Postgres95 '{ databaseName = test; hostName = localhost; userName = postgres; password = postgres; }'\n"
-      "\t         Attempts to connect to a Postgres database on host localhost.\n"
+      "\tExample: eoutil connect PostgreSQL '{ databaseName = test; hostName = localhost; userName = postgres; password = postgres; }'\n"
+      "\t         Attempts to connect to a PostgreSQL database on host localhost.\n"
       "\n"
       "  eoutil help\n"
       "\tPrints this text.\n"
