@@ -1,12 +1,12 @@
 /* <title>This tool produce .gsdoc files from eomodel files</title>
 
-   Copyright (C) 2000-2002 Free Software Foundation, Inc.
+   Copyright (C) 2000-2002,2003,2004,2005 Free Software Foundation, Inc.
 
    Written by:	Manuel Guesdon <mguesdon@orange-concept.com>
    Created: August 2000
 
-   $Revision: 1.5 $
-   $Date: 2004/03/19 16:41:21 $
+   $Revision: 21645 $
+   $Date: 2005-08-17 10:07:57 +0200 (Mit, 17 Aug 2005) $
 
    <abstract></abstract>
 
@@ -26,25 +26,26 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
    </license>
 **/
 
 #include "config.h"
 
-RCS_ID("$Id: gsdoc-model.m,v 1.5 2004/03/19 16:41:21 ayers Exp $")
+RCS_ID("$Id: gsdoc-model.m 21645 2005-08-17 08:07:57Z ayers $")
 
 #ifdef GNUSTEP
-#include <Foundation/NSString.h>
 #include <Foundation/NSArray.h>
+#include <Foundation/NSAutoreleasePool.h>
+#include <Foundation/NSCalendarDate.h>
 #include <Foundation/NSDictionary.h>
 #include <Foundation/NSEnumerator.h>
+#include <Foundation/NSException.h>
 #include <Foundation/NSFileManager.h>
 #include <Foundation/NSProcessInfo.h>
 #include <Foundation/NSSet.h>
+#include <Foundation/NSString.h>
 #include <Foundation/NSUserDefaults.h>
-#include <Foundation/NSAutoreleasePool.h>
-#include <Foundation/NSException.h>
 #else
 #include <Foundation/Foundation.h>
 #endif
